# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = ['ResourceShareAccepterArgs', 'ResourceShareAccepter']

@pulumi.input_type
class ResourceShareAccepterArgs:
    def __init__(__self__, *,
                 share_arn: pulumi.Input[str]):
        """
        The set of arguments for constructing a ResourceShareAccepter resource.
        :param pulumi.Input[str] share_arn: The ARN of the resource share.
        """
        pulumi.set(__self__, "share_arn", share_arn)

    @property
    @pulumi.getter(name="shareArn")
    def share_arn(self) -> pulumi.Input[str]:
        """
        The ARN of the resource share.
        """
        return pulumi.get(self, "share_arn")

    @share_arn.setter
    def share_arn(self, value: pulumi.Input[str]):
        pulumi.set(self, "share_arn", value)


@pulumi.input_type
class _ResourceShareAccepterState:
    def __init__(__self__, *,
                 invitation_arn: Optional[pulumi.Input[str]] = None,
                 receiver_account_id: Optional[pulumi.Input[str]] = None,
                 resources: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 sender_account_id: Optional[pulumi.Input[str]] = None,
                 share_arn: Optional[pulumi.Input[str]] = None,
                 share_id: Optional[pulumi.Input[str]] = None,
                 share_name: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering ResourceShareAccepter resources.
        :param pulumi.Input[str] invitation_arn: The ARN of the resource share invitation.
        :param pulumi.Input[str] receiver_account_id: The account ID of the receiver account which accepts the invitation.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] resources: A list of the resource ARNs shared via the resource share.
        :param pulumi.Input[str] sender_account_id: The account ID of the sender account which submits the invitation.
        :param pulumi.Input[str] share_arn: The ARN of the resource share.
        :param pulumi.Input[str] share_id: The ID of the resource share as displayed in the console.
        :param pulumi.Input[str] share_name: The name of the resource share.
        :param pulumi.Input[str] status: The status of the resource share (ACTIVE, PENDING, FAILED, DELETING, DELETED).
        """
        if invitation_arn is not None:
            pulumi.set(__self__, "invitation_arn", invitation_arn)
        if receiver_account_id is not None:
            pulumi.set(__self__, "receiver_account_id", receiver_account_id)
        if resources is not None:
            pulumi.set(__self__, "resources", resources)
        if sender_account_id is not None:
            pulumi.set(__self__, "sender_account_id", sender_account_id)
        if share_arn is not None:
            pulumi.set(__self__, "share_arn", share_arn)
        if share_id is not None:
            pulumi.set(__self__, "share_id", share_id)
        if share_name is not None:
            pulumi.set(__self__, "share_name", share_name)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter(name="invitationArn")
    def invitation_arn(self) -> Optional[pulumi.Input[str]]:
        """
        The ARN of the resource share invitation.
        """
        return pulumi.get(self, "invitation_arn")

    @invitation_arn.setter
    def invitation_arn(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "invitation_arn", value)

    @property
    @pulumi.getter(name="receiverAccountId")
    def receiver_account_id(self) -> Optional[pulumi.Input[str]]:
        """
        The account ID of the receiver account which accepts the invitation.
        """
        return pulumi.get(self, "receiver_account_id")

    @receiver_account_id.setter
    def receiver_account_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "receiver_account_id", value)

    @property
    @pulumi.getter
    def resources(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        A list of the resource ARNs shared via the resource share.
        """
        return pulumi.get(self, "resources")

    @resources.setter
    def resources(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "resources", value)

    @property
    @pulumi.getter(name="senderAccountId")
    def sender_account_id(self) -> Optional[pulumi.Input[str]]:
        """
        The account ID of the sender account which submits the invitation.
        """
        return pulumi.get(self, "sender_account_id")

    @sender_account_id.setter
    def sender_account_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "sender_account_id", value)

    @property
    @pulumi.getter(name="shareArn")
    def share_arn(self) -> Optional[pulumi.Input[str]]:
        """
        The ARN of the resource share.
        """
        return pulumi.get(self, "share_arn")

    @share_arn.setter
    def share_arn(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "share_arn", value)

    @property
    @pulumi.getter(name="shareId")
    def share_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the resource share as displayed in the console.
        """
        return pulumi.get(self, "share_id")

    @share_id.setter
    def share_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "share_id", value)

    @property
    @pulumi.getter(name="shareName")
    def share_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the resource share.
        """
        return pulumi.get(self, "share_name")

    @share_name.setter
    def share_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "share_name", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[str]]:
        """
        The status of the resource share (ACTIVE, PENDING, FAILED, DELETING, DELETED).
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "status", value)


class ResourceShareAccepter(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 share_arn: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Manage accepting a Resource Access Manager (RAM) Resource Share invitation. From a _receiver_ AWS account, accept an invitation to share resources that were shared by a _sender_ AWS account. To create a resource share in the _sender_, see the `ram.ResourceShare` resource.

        > **Note:** If both AWS accounts are in the same Organization and [RAM Sharing with AWS Organizations is enabled](https://docs.aws.amazon.com/ram/latest/userguide/getting-started-sharing.html#getting-started-sharing-orgs), this resource is not necessary as RAM Resource Share invitations are not used.

        ## Example Usage

        This configuration provides an example of using multiple AWS providers to configure two different AWS accounts. In the _sender_ account, the configuration creates a `ram.ResourceShare` and uses a data source in the _receiver_ account to create a `ram.PrincipalAssociation` resource with the _receiver's_ account ID. In the _receiver_ account, the configuration accepts the invitation to share resources with the `ram.ResourceShareAccepter`.

        ```python
        import pulumi
        import pulumi_aws as aws
        import pulumi_pulumi as pulumi

        alternate = pulumi.providers.Aws("alternate", profile="profile1")
        sender_share = aws.ram.ResourceShare("senderShare",
            allow_external_principals=True,
            tags={
                "Name": "tf-test-resource-share",
            },
            opts=pulumi.ResourceOptions(provider=aws["alternate"]))
        receiver = aws.get_caller_identity()
        sender_invite = aws.ram.PrincipalAssociation("senderInvite",
            principal=receiver.account_id,
            resource_share_arn=sender_share.arn,
            opts=pulumi.ResourceOptions(provider=aws["alternate"]))
        receiver_accept = aws.ram.ResourceShareAccepter("receiverAccept", share_arn=sender_invite.resource_share_arn)
        ```

        ## Import

        Resource share accepters can be imported using the resource share ARN, e.g.,

        ```sh
         $ pulumi import aws:ram/resourceShareAccepter:ResourceShareAccepter example arn:aws:ram:us-east-1:123456789012:resource-share/c4b56393-e8d9-89d9-6dc9-883752de4767
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] share_arn: The ARN of the resource share.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ResourceShareAccepterArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manage accepting a Resource Access Manager (RAM) Resource Share invitation. From a _receiver_ AWS account, accept an invitation to share resources that were shared by a _sender_ AWS account. To create a resource share in the _sender_, see the `ram.ResourceShare` resource.

        > **Note:** If both AWS accounts are in the same Organization and [RAM Sharing with AWS Organizations is enabled](https://docs.aws.amazon.com/ram/latest/userguide/getting-started-sharing.html#getting-started-sharing-orgs), this resource is not necessary as RAM Resource Share invitations are not used.

        ## Example Usage

        This configuration provides an example of using multiple AWS providers to configure two different AWS accounts. In the _sender_ account, the configuration creates a `ram.ResourceShare` and uses a data source in the _receiver_ account to create a `ram.PrincipalAssociation` resource with the _receiver's_ account ID. In the _receiver_ account, the configuration accepts the invitation to share resources with the `ram.ResourceShareAccepter`.

        ```python
        import pulumi
        import pulumi_aws as aws
        import pulumi_pulumi as pulumi

        alternate = pulumi.providers.Aws("alternate", profile="profile1")
        sender_share = aws.ram.ResourceShare("senderShare",
            allow_external_principals=True,
            tags={
                "Name": "tf-test-resource-share",
            },
            opts=pulumi.ResourceOptions(provider=aws["alternate"]))
        receiver = aws.get_caller_identity()
        sender_invite = aws.ram.PrincipalAssociation("senderInvite",
            principal=receiver.account_id,
            resource_share_arn=sender_share.arn,
            opts=pulumi.ResourceOptions(provider=aws["alternate"]))
        receiver_accept = aws.ram.ResourceShareAccepter("receiverAccept", share_arn=sender_invite.resource_share_arn)
        ```

        ## Import

        Resource share accepters can be imported using the resource share ARN, e.g.,

        ```sh
         $ pulumi import aws:ram/resourceShareAccepter:ResourceShareAccepter example arn:aws:ram:us-east-1:123456789012:resource-share/c4b56393-e8d9-89d9-6dc9-883752de4767
        ```

        :param str resource_name: The name of the resource.
        :param ResourceShareAccepterArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ResourceShareAccepterArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 share_arn: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = _utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ResourceShareAccepterArgs.__new__(ResourceShareAccepterArgs)

            if share_arn is None and not opts.urn:
                raise TypeError("Missing required property 'share_arn'")
            __props__.__dict__["share_arn"] = share_arn
            __props__.__dict__["invitation_arn"] = None
            __props__.__dict__["receiver_account_id"] = None
            __props__.__dict__["resources"] = None
            __props__.__dict__["sender_account_id"] = None
            __props__.__dict__["share_id"] = None
            __props__.__dict__["share_name"] = None
            __props__.__dict__["status"] = None
        super(ResourceShareAccepter, __self__).__init__(
            'aws:ram/resourceShareAccepter:ResourceShareAccepter',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            invitation_arn: Optional[pulumi.Input[str]] = None,
            receiver_account_id: Optional[pulumi.Input[str]] = None,
            resources: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            sender_account_id: Optional[pulumi.Input[str]] = None,
            share_arn: Optional[pulumi.Input[str]] = None,
            share_id: Optional[pulumi.Input[str]] = None,
            share_name: Optional[pulumi.Input[str]] = None,
            status: Optional[pulumi.Input[str]] = None) -> 'ResourceShareAccepter':
        """
        Get an existing ResourceShareAccepter resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] invitation_arn: The ARN of the resource share invitation.
        :param pulumi.Input[str] receiver_account_id: The account ID of the receiver account which accepts the invitation.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] resources: A list of the resource ARNs shared via the resource share.
        :param pulumi.Input[str] sender_account_id: The account ID of the sender account which submits the invitation.
        :param pulumi.Input[str] share_arn: The ARN of the resource share.
        :param pulumi.Input[str] share_id: The ID of the resource share as displayed in the console.
        :param pulumi.Input[str] share_name: The name of the resource share.
        :param pulumi.Input[str] status: The status of the resource share (ACTIVE, PENDING, FAILED, DELETING, DELETED).
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ResourceShareAccepterState.__new__(_ResourceShareAccepterState)

        __props__.__dict__["invitation_arn"] = invitation_arn
        __props__.__dict__["receiver_account_id"] = receiver_account_id
        __props__.__dict__["resources"] = resources
        __props__.__dict__["sender_account_id"] = sender_account_id
        __props__.__dict__["share_arn"] = share_arn
        __props__.__dict__["share_id"] = share_id
        __props__.__dict__["share_name"] = share_name
        __props__.__dict__["status"] = status
        return ResourceShareAccepter(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="invitationArn")
    def invitation_arn(self) -> pulumi.Output[str]:
        """
        The ARN of the resource share invitation.
        """
        return pulumi.get(self, "invitation_arn")

    @property
    @pulumi.getter(name="receiverAccountId")
    def receiver_account_id(self) -> pulumi.Output[str]:
        """
        The account ID of the receiver account which accepts the invitation.
        """
        return pulumi.get(self, "receiver_account_id")

    @property
    @pulumi.getter
    def resources(self) -> pulumi.Output[Sequence[str]]:
        """
        A list of the resource ARNs shared via the resource share.
        """
        return pulumi.get(self, "resources")

    @property
    @pulumi.getter(name="senderAccountId")
    def sender_account_id(self) -> pulumi.Output[str]:
        """
        The account ID of the sender account which submits the invitation.
        """
        return pulumi.get(self, "sender_account_id")

    @property
    @pulumi.getter(name="shareArn")
    def share_arn(self) -> pulumi.Output[str]:
        """
        The ARN of the resource share.
        """
        return pulumi.get(self, "share_arn")

    @property
    @pulumi.getter(name="shareId")
    def share_id(self) -> pulumi.Output[str]:
        """
        The ID of the resource share as displayed in the console.
        """
        return pulumi.get(self, "share_id")

    @property
    @pulumi.getter(name="shareName")
    def share_name(self) -> pulumi.Output[str]:
        """
        The name of the resource share.
        """
        return pulumi.get(self, "share_name")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[str]:
        """
        The status of the resource share (ACTIVE, PENDING, FAILED, DELETING, DELETED).
        """
        return pulumi.get(self, "status")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'DevicePoolRule',
]

@pulumi.output_type
class DevicePoolRule(dict):
    def __init__(__self__, *,
                 attribute: Optional[str] = None,
                 operator: Optional[str] = None,
                 value: Optional[str] = None):
        """
        :param str attribute: The rule's stringified attribute. Valid values are: `APPIUM_VERSION`, `ARN`, `AVAILABILITY`, `FLEET_TYPE`, `FORM_FACTOR`, `INSTANCE_ARN`, `INSTANCE_LABELS`, `MANUFACTURER`, `MODEL`, `OS_VERSION`, `PLATFORM`, `REMOTE_ACCESS_ENABLED`, `REMOTE_DEBUG_ENABLED`.
        :param str operator: Specifies how Device Farm compares the rule's attribute to the value. For the operators that are supported by each attribute. Valid values are: `EQUALS`, `NOT_IN`, `IN`, `GREATER_THAN`, `GREATER_THAN_OR_EQUALS`, `LESS_THAN`, `LESS_THAN_OR_EQUALS`, `CONTAINS`.
        :param str value: The rule's value.
        """
        if attribute is not None:
            pulumi.set(__self__, "attribute", attribute)
        if operator is not None:
            pulumi.set(__self__, "operator", operator)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def attribute(self) -> Optional[str]:
        """
        The rule's stringified attribute. Valid values are: `APPIUM_VERSION`, `ARN`, `AVAILABILITY`, `FLEET_TYPE`, `FORM_FACTOR`, `INSTANCE_ARN`, `INSTANCE_LABELS`, `MANUFACTURER`, `MODEL`, `OS_VERSION`, `PLATFORM`, `REMOTE_ACCESS_ENABLED`, `REMOTE_DEBUG_ENABLED`.
        """
        return pulumi.get(self, "attribute")

    @property
    @pulumi.getter
    def operator(self) -> Optional[str]:
        """
        Specifies how Device Farm compares the rule's attribute to the value. For the operators that are supported by each attribute. Valid values are: `EQUALS`, `NOT_IN`, `IN`, `GREATER_THAN`, `GREATER_THAN_OR_EQUALS`, `LESS_THAN`, `LESS_THAN_OR_EQUALS`, `CONTAINS`.
        """
        return pulumi.get(self, "operator")

    @property
    @pulumi.getter
    def value(self) -> Optional[str]:
        """
        The rule's value.
        """
        return pulumi.get(self, "value")





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'BotAssociationLexBotArgs',
    'HoursOfOperationConfigArgs',
    'HoursOfOperationConfigEndTimeArgs',
    'HoursOfOperationConfigStartTimeArgs',
    'QuickConnectQuickConnectConfigArgs',
    'QuickConnectQuickConnectConfigPhoneConfigArgs',
    'QuickConnectQuickConnectConfigQueueConfigArgs',
    'QuickConnectQuickConnectConfigUserConfigArgs',
    'GetBotAssociationLexBotArgs',
]

@pulumi.input_type
class BotAssociationLexBotArgs:
    def __init__(__self__, *,
                 name: pulumi.Input[str],
                 lex_region: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] name: The name of the Amazon Lex (V1) bot.
        :param pulumi.Input[str] lex_region: The Region that the Amazon Lex (V1) bot was created in. Defaults to current region.
        """
        pulumi.set(__self__, "name", name)
        if lex_region is not None:
            pulumi.set(__self__, "lex_region", lex_region)

    @property
    @pulumi.getter
    def name(self) -> pulumi.Input[str]:
        """
        The name of the Amazon Lex (V1) bot.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: pulumi.Input[str]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="lexRegion")
    def lex_region(self) -> Optional[pulumi.Input[str]]:
        """
        The Region that the Amazon Lex (V1) bot was created in. Defaults to current region.
        """
        return pulumi.get(self, "lex_region")

    @lex_region.setter
    def lex_region(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "lex_region", value)


@pulumi.input_type
class HoursOfOperationConfigArgs:
    def __init__(__self__, *,
                 day: pulumi.Input[str],
                 end_time: pulumi.Input['HoursOfOperationConfigEndTimeArgs'],
                 start_time: pulumi.Input['HoursOfOperationConfigStartTimeArgs']):
        """
        :param pulumi.Input[str] day: Specifies the day that the hours of operation applies to.
        :param pulumi.Input['HoursOfOperationConfigEndTimeArgs'] end_time: A end time block specifies the time that your contact center closes. The `end_time` is documented below.
        :param pulumi.Input['HoursOfOperationConfigStartTimeArgs'] start_time: A start time block specifies the time that your contact center opens. The `start_time` is documented below.
        """
        pulumi.set(__self__, "day", day)
        pulumi.set(__self__, "end_time", end_time)
        pulumi.set(__self__, "start_time", start_time)

    @property
    @pulumi.getter
    def day(self) -> pulumi.Input[str]:
        """
        Specifies the day that the hours of operation applies to.
        """
        return pulumi.get(self, "day")

    @day.setter
    def day(self, value: pulumi.Input[str]):
        pulumi.set(self, "day", value)

    @property
    @pulumi.getter(name="endTime")
    def end_time(self) -> pulumi.Input['HoursOfOperationConfigEndTimeArgs']:
        """
        A end time block specifies the time that your contact center closes. The `end_time` is documented below.
        """
        return pulumi.get(self, "end_time")

    @end_time.setter
    def end_time(self, value: pulumi.Input['HoursOfOperationConfigEndTimeArgs']):
        pulumi.set(self, "end_time", value)

    @property
    @pulumi.getter(name="startTime")
    def start_time(self) -> pulumi.Input['HoursOfOperationConfigStartTimeArgs']:
        """
        A start time block specifies the time that your contact center opens. The `start_time` is documented below.
        """
        return pulumi.get(self, "start_time")

    @start_time.setter
    def start_time(self, value: pulumi.Input['HoursOfOperationConfigStartTimeArgs']):
        pulumi.set(self, "start_time", value)


@pulumi.input_type
class HoursOfOperationConfigEndTimeArgs:
    def __init__(__self__, *,
                 hours: pulumi.Input[int],
                 minutes: pulumi.Input[int]):
        """
        :param pulumi.Input[int] hours: Specifies the hour of closing.
        :param pulumi.Input[int] minutes: Specifies the minute of closing.
        """
        pulumi.set(__self__, "hours", hours)
        pulumi.set(__self__, "minutes", minutes)

    @property
    @pulumi.getter
    def hours(self) -> pulumi.Input[int]:
        """
        Specifies the hour of closing.
        """
        return pulumi.get(self, "hours")

    @hours.setter
    def hours(self, value: pulumi.Input[int]):
        pulumi.set(self, "hours", value)

    @property
    @pulumi.getter
    def minutes(self) -> pulumi.Input[int]:
        """
        Specifies the minute of closing.
        """
        return pulumi.get(self, "minutes")

    @minutes.setter
    def minutes(self, value: pulumi.Input[int]):
        pulumi.set(self, "minutes", value)


@pulumi.input_type
class HoursOfOperationConfigStartTimeArgs:
    def __init__(__self__, *,
                 hours: pulumi.Input[int],
                 minutes: pulumi.Input[int]):
        """
        :param pulumi.Input[int] hours: Specifies the hour of opening.
        :param pulumi.Input[int] minutes: Specifies the minute of opening.
        """
        pulumi.set(__self__, "hours", hours)
        pulumi.set(__self__, "minutes", minutes)

    @property
    @pulumi.getter
    def hours(self) -> pulumi.Input[int]:
        """
        Specifies the hour of opening.
        """
        return pulumi.get(self, "hours")

    @hours.setter
    def hours(self, value: pulumi.Input[int]):
        pulumi.set(self, "hours", value)

    @property
    @pulumi.getter
    def minutes(self) -> pulumi.Input[int]:
        """
        Specifies the minute of opening.
        """
        return pulumi.get(self, "minutes")

    @minutes.setter
    def minutes(self, value: pulumi.Input[int]):
        pulumi.set(self, "minutes", value)


@pulumi.input_type
class QuickConnectQuickConnectConfigArgs:
    def __init__(__self__, *,
                 quick_connect_type: pulumi.Input[str],
                 phone_configs: Optional[pulumi.Input[Sequence[pulumi.Input['QuickConnectQuickConnectConfigPhoneConfigArgs']]]] = None,
                 queue_configs: Optional[pulumi.Input[Sequence[pulumi.Input['QuickConnectQuickConnectConfigQueueConfigArgs']]]] = None,
                 user_configs: Optional[pulumi.Input[Sequence[pulumi.Input['QuickConnectQuickConnectConfigUserConfigArgs']]]] = None):
        """
        :param pulumi.Input[str] quick_connect_type: Specifies the configuration type of the quick connect. valid values are `PHONE_NUMBER`, `QUEUE`, `USER`.
        :param pulumi.Input[Sequence[pulumi.Input['QuickConnectQuickConnectConfigPhoneConfigArgs']]] phone_configs: Specifies the phone configuration of the Quick Connect. This is required only if `quick_connect_type` is `PHONE_NUMBER`. The `phone_config` block is documented below.
        :param pulumi.Input[Sequence[pulumi.Input['QuickConnectQuickConnectConfigQueueConfigArgs']]] queue_configs: Specifies the queue configuration of the Quick Connect. This is required only if `quick_connect_type` is `QUEUE`. The `queue_config` block is documented below.
        :param pulumi.Input[Sequence[pulumi.Input['QuickConnectQuickConnectConfigUserConfigArgs']]] user_configs: Specifies the user configuration of the Quick Connect. This is required only if `quick_connect_type` is `USER`. The `user_config` block is documented below.
        """
        pulumi.set(__self__, "quick_connect_type", quick_connect_type)
        if phone_configs is not None:
            pulumi.set(__self__, "phone_configs", phone_configs)
        if queue_configs is not None:
            pulumi.set(__self__, "queue_configs", queue_configs)
        if user_configs is not None:
            pulumi.set(__self__, "user_configs", user_configs)

    @property
    @pulumi.getter(name="quickConnectType")
    def quick_connect_type(self) -> pulumi.Input[str]:
        """
        Specifies the configuration type of the quick connect. valid values are `PHONE_NUMBER`, `QUEUE`, `USER`.
        """
        return pulumi.get(self, "quick_connect_type")

    @quick_connect_type.setter
    def quick_connect_type(self, value: pulumi.Input[str]):
        pulumi.set(self, "quick_connect_type", value)

    @property
    @pulumi.getter(name="phoneConfigs")
    def phone_configs(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['QuickConnectQuickConnectConfigPhoneConfigArgs']]]]:
        """
        Specifies the phone configuration of the Quick Connect. This is required only if `quick_connect_type` is `PHONE_NUMBER`. The `phone_config` block is documented below.
        """
        return pulumi.get(self, "phone_configs")

    @phone_configs.setter
    def phone_configs(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['QuickConnectQuickConnectConfigPhoneConfigArgs']]]]):
        pulumi.set(self, "phone_configs", value)

    @property
    @pulumi.getter(name="queueConfigs")
    def queue_configs(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['QuickConnectQuickConnectConfigQueueConfigArgs']]]]:
        """
        Specifies the queue configuration of the Quick Connect. This is required only if `quick_connect_type` is `QUEUE`. The `queue_config` block is documented below.
        """
        return pulumi.get(self, "queue_configs")

    @queue_configs.setter
    def queue_configs(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['QuickConnectQuickConnectConfigQueueConfigArgs']]]]):
        pulumi.set(self, "queue_configs", value)

    @property
    @pulumi.getter(name="userConfigs")
    def user_configs(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['QuickConnectQuickConnectConfigUserConfigArgs']]]]:
        """
        Specifies the user configuration of the Quick Connect. This is required only if `quick_connect_type` is `USER`. The `user_config` block is documented below.
        """
        return pulumi.get(self, "user_configs")

    @user_configs.setter
    def user_configs(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['QuickConnectQuickConnectConfigUserConfigArgs']]]]):
        pulumi.set(self, "user_configs", value)


@pulumi.input_type
class QuickConnectQuickConnectConfigPhoneConfigArgs:
    def __init__(__self__, *,
                 phone_number: pulumi.Input[str]):
        """
        :param pulumi.Input[str] phone_number: Specifies the phone number in in E.164 format.
        """
        pulumi.set(__self__, "phone_number", phone_number)

    @property
    @pulumi.getter(name="phoneNumber")
    def phone_number(self) -> pulumi.Input[str]:
        """
        Specifies the phone number in in E.164 format.
        """
        return pulumi.get(self, "phone_number")

    @phone_number.setter
    def phone_number(self, value: pulumi.Input[str]):
        pulumi.set(self, "phone_number", value)


@pulumi.input_type
class QuickConnectQuickConnectConfigQueueConfigArgs:
    def __init__(__self__, *,
                 contact_flow_id: pulumi.Input[str],
                 queue_id: pulumi.Input[str]):
        """
        :param pulumi.Input[str] contact_flow_id: Specifies the identifier of the contact flow.
        :param pulumi.Input[str] queue_id: Specifies the identifier for the queue.
        """
        pulumi.set(__self__, "contact_flow_id", contact_flow_id)
        pulumi.set(__self__, "queue_id", queue_id)

    @property
    @pulumi.getter(name="contactFlowId")
    def contact_flow_id(self) -> pulumi.Input[str]:
        """
        Specifies the identifier of the contact flow.
        """
        return pulumi.get(self, "contact_flow_id")

    @contact_flow_id.setter
    def contact_flow_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "contact_flow_id", value)

    @property
    @pulumi.getter(name="queueId")
    def queue_id(self) -> pulumi.Input[str]:
        """
        Specifies the identifier for the queue.
        """
        return pulumi.get(self, "queue_id")

    @queue_id.setter
    def queue_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "queue_id", value)


@pulumi.input_type
class QuickConnectQuickConnectConfigUserConfigArgs:
    def __init__(__self__, *,
                 contact_flow_id: pulumi.Input[str],
                 user_id: pulumi.Input[str]):
        """
        :param pulumi.Input[str] contact_flow_id: Specifies the identifier of the contact flow.
        :param pulumi.Input[str] user_id: Specifies the identifier for the user.
        """
        pulumi.set(__self__, "contact_flow_id", contact_flow_id)
        pulumi.set(__self__, "user_id", user_id)

    @property
    @pulumi.getter(name="contactFlowId")
    def contact_flow_id(self) -> pulumi.Input[str]:
        """
        Specifies the identifier of the contact flow.
        """
        return pulumi.get(self, "contact_flow_id")

    @contact_flow_id.setter
    def contact_flow_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "contact_flow_id", value)

    @property
    @pulumi.getter(name="userId")
    def user_id(self) -> pulumi.Input[str]:
        """
        Specifies the identifier for the user.
        """
        return pulumi.get(self, "user_id")

    @user_id.setter
    def user_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "user_id", value)


@pulumi.input_type
class GetBotAssociationLexBotArgs:
    def __init__(__self__, *,
                 lex_region: str,
                 name: str):
        """
        :param str lex_region: The Region that the Amazon Lex (V1) bot was created in.
        :param str name: The name of the Amazon Lex (V1) bot.
        """
        pulumi.set(__self__, "lex_region", lex_region)
        pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter(name="lexRegion")
    def lex_region(self) -> str:
        """
        The Region that the Amazon Lex (V1) bot was created in.
        """
        return pulumi.get(self, "lex_region")

    @lex_region.setter
    def lex_region(self, value: str):
        pulumi.set(self, "lex_region", value)

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        The name of the Amazon Lex (V1) bot.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: str):
        pulumi.set(self, "name", value)





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

__all__ = [
    'PlanAdvancedBackupSetting',
    'PlanRule',
    'PlanRuleCopyAction',
    'PlanRuleCopyActionLifecycle',
    'PlanRuleLifecycle',
    'SelectionCondition',
    'SelectionConditionStringEqual',
    'SelectionConditionStringLike',
    'SelectionConditionStringNotEqual',
    'SelectionConditionStringNotLike',
    'SelectionSelectionTag',
]

@pulumi.output_type
class PlanAdvancedBackupSetting(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "backupOptions":
            suggest = "backup_options"
        elif key == "resourceType":
            suggest = "resource_type"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in PlanAdvancedBackupSetting. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        PlanAdvancedBackupSetting.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        PlanAdvancedBackupSetting.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 backup_options: Mapping[str, str],
                 resource_type: str):
        """
        :param Mapping[str, str] backup_options: Specifies the backup option for a selected resource. This option is only available for Windows VSS backup jobs. Set to `{ WindowsVSS = "enabled" }` to enable Windows VSS backup option and create a VSS Windows backup.
        :param str resource_type: The type of AWS resource to be backed up. For VSS Windows backups, the only supported resource type is Amazon EC2. Valid values: `EC2`.
        """
        pulumi.set(__self__, "backup_options", backup_options)
        pulumi.set(__self__, "resource_type", resource_type)

    @property
    @pulumi.getter(name="backupOptions")
    def backup_options(self) -> Mapping[str, str]:
        """
        Specifies the backup option for a selected resource. This option is only available for Windows VSS backup jobs. Set to `{ WindowsVSS = "enabled" }` to enable Windows VSS backup option and create a VSS Windows backup.
        """
        return pulumi.get(self, "backup_options")

    @property
    @pulumi.getter(name="resourceType")
    def resource_type(self) -> str:
        """
        The type of AWS resource to be backed up. For VSS Windows backups, the only supported resource type is Amazon EC2. Valid values: `EC2`.
        """
        return pulumi.get(self, "resource_type")


@pulumi.output_type
class PlanRule(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "ruleName":
            suggest = "rule_name"
        elif key == "targetVaultName":
            suggest = "target_vault_name"
        elif key == "completionWindow":
            suggest = "completion_window"
        elif key == "copyActions":
            suggest = "copy_actions"
        elif key == "enableContinuousBackup":
            suggest = "enable_continuous_backup"
        elif key == "recoveryPointTags":
            suggest = "recovery_point_tags"
        elif key == "startWindow":
            suggest = "start_window"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in PlanRule. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        PlanRule.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        PlanRule.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 rule_name: str,
                 target_vault_name: str,
                 completion_window: Optional[int] = None,
                 copy_actions: Optional[Sequence['outputs.PlanRuleCopyAction']] = None,
                 enable_continuous_backup: Optional[bool] = None,
                 lifecycle: Optional['outputs.PlanRuleLifecycle'] = None,
                 recovery_point_tags: Optional[Mapping[str, str]] = None,
                 schedule: Optional[str] = None,
                 start_window: Optional[int] = None):
        """
        :param str rule_name: An display name for a backup rule.
        :param str target_vault_name: The name of a logical container where backups are stored.
        :param int completion_window: The amount of time AWS Backup attempts a backup before canceling the job and returning an error.
        :param Sequence['PlanRuleCopyActionArgs'] copy_actions: Configuration block(s) with copy operation settings. Detailed below.
        :param bool enable_continuous_backup: Enable continuous backups for supported resources.
        :param 'PlanRuleLifecycleArgs' lifecycle: The lifecycle defines when a protected resource is copied over to a backup vault and when it expires.  Fields documented above.
        :param Mapping[str, str] recovery_point_tags: Metadata that you can assign to help organize the resources that you create.
        :param str schedule: A CRON expression specifying when AWS Backup initiates a backup job.
        :param int start_window: The amount of time in minutes before beginning a backup.
        """
        pulumi.set(__self__, "rule_name", rule_name)
        pulumi.set(__self__, "target_vault_name", target_vault_name)
        if completion_window is not None:
            pulumi.set(__self__, "completion_window", completion_window)
        if copy_actions is not None:
            pulumi.set(__self__, "copy_actions", copy_actions)
        if enable_continuous_backup is not None:
            pulumi.set(__self__, "enable_continuous_backup", enable_continuous_backup)
        if lifecycle is not None:
            pulumi.set(__self__, "lifecycle", lifecycle)
        if recovery_point_tags is not None:
            pulumi.set(__self__, "recovery_point_tags", recovery_point_tags)
        if schedule is not None:
            pulumi.set(__self__, "schedule", schedule)
        if start_window is not None:
            pulumi.set(__self__, "start_window", start_window)

    @property
    @pulumi.getter(name="ruleName")
    def rule_name(self) -> str:
        """
        An display name for a backup rule.
        """
        return pulumi.get(self, "rule_name")

    @property
    @pulumi.getter(name="targetVaultName")
    def target_vault_name(self) -> str:
        """
        The name of a logical container where backups are stored.
        """
        return pulumi.get(self, "target_vault_name")

    @property
    @pulumi.getter(name="completionWindow")
    def completion_window(self) -> Optional[int]:
        """
        The amount of time AWS Backup attempts a backup before canceling the job and returning an error.
        """
        return pulumi.get(self, "completion_window")

    @property
    @pulumi.getter(name="copyActions")
    def copy_actions(self) -> Optional[Sequence['outputs.PlanRuleCopyAction']]:
        """
        Configuration block(s) with copy operation settings. Detailed below.
        """
        return pulumi.get(self, "copy_actions")

    @property
    @pulumi.getter(name="enableContinuousBackup")
    def enable_continuous_backup(self) -> Optional[bool]:
        """
        Enable continuous backups for supported resources.
        """
        return pulumi.get(self, "enable_continuous_backup")

    @property
    @pulumi.getter
    def lifecycle(self) -> Optional['outputs.PlanRuleLifecycle']:
        """
        The lifecycle defines when a protected resource is copied over to a backup vault and when it expires.  Fields documented above.
        """
        return pulumi.get(self, "lifecycle")

    @property
    @pulumi.getter(name="recoveryPointTags")
    def recovery_point_tags(self) -> Optional[Mapping[str, str]]:
        """
        Metadata that you can assign to help organize the resources that you create.
        """
        return pulumi.get(self, "recovery_point_tags")

    @property
    @pulumi.getter
    def schedule(self) -> Optional[str]:
        """
        A CRON expression specifying when AWS Backup initiates a backup job.
        """
        return pulumi.get(self, "schedule")

    @property
    @pulumi.getter(name="startWindow")
    def start_window(self) -> Optional[int]:
        """
        The amount of time in minutes before beginning a backup.
        """
        return pulumi.get(self, "start_window")


@pulumi.output_type
class PlanRuleCopyAction(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "destinationVaultArn":
            suggest = "destination_vault_arn"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in PlanRuleCopyAction. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        PlanRuleCopyAction.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        PlanRuleCopyAction.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 destination_vault_arn: str,
                 lifecycle: Optional['outputs.PlanRuleCopyActionLifecycle'] = None):
        """
        :param str destination_vault_arn: An Amazon Resource Name (ARN) that uniquely identifies the destination backup vault for the copied backup.
        :param 'PlanRuleCopyActionLifecycleArgs' lifecycle: The lifecycle defines when a protected resource is copied over to a backup vault and when it expires.  Fields documented above.
        """
        pulumi.set(__self__, "destination_vault_arn", destination_vault_arn)
        if lifecycle is not None:
            pulumi.set(__self__, "lifecycle", lifecycle)

    @property
    @pulumi.getter(name="destinationVaultArn")
    def destination_vault_arn(self) -> str:
        """
        An Amazon Resource Name (ARN) that uniquely identifies the destination backup vault for the copied backup.
        """
        return pulumi.get(self, "destination_vault_arn")

    @property
    @pulumi.getter
    def lifecycle(self) -> Optional['outputs.PlanRuleCopyActionLifecycle']:
        """
        The lifecycle defines when a protected resource is copied over to a backup vault and when it expires.  Fields documented above.
        """
        return pulumi.get(self, "lifecycle")


@pulumi.output_type
class PlanRuleCopyActionLifecycle(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "coldStorageAfter":
            suggest = "cold_storage_after"
        elif key == "deleteAfter":
            suggest = "delete_after"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in PlanRuleCopyActionLifecycle. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        PlanRuleCopyActionLifecycle.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        PlanRuleCopyActionLifecycle.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 cold_storage_after: Optional[int] = None,
                 delete_after: Optional[int] = None):
        """
        :param int cold_storage_after: Specifies the number of days after creation that a recovery point is moved to cold storage.
        :param int delete_after: Specifies the number of days after creation that a recovery point is deleted. Must be 90 days greater than `cold_storage_after`.
        """
        if cold_storage_after is not None:
            pulumi.set(__self__, "cold_storage_after", cold_storage_after)
        if delete_after is not None:
            pulumi.set(__self__, "delete_after", delete_after)

    @property
    @pulumi.getter(name="coldStorageAfter")
    def cold_storage_after(self) -> Optional[int]:
        """
        Specifies the number of days after creation that a recovery point is moved to cold storage.
        """
        return pulumi.get(self, "cold_storage_after")

    @property
    @pulumi.getter(name="deleteAfter")
    def delete_after(self) -> Optional[int]:
        """
        Specifies the number of days after creation that a recovery point is deleted. Must be 90 days greater than `cold_storage_after`.
        """
        return pulumi.get(self, "delete_after")


@pulumi.output_type
class PlanRuleLifecycle(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "coldStorageAfter":
            suggest = "cold_storage_after"
        elif key == "deleteAfter":
            suggest = "delete_after"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in PlanRuleLifecycle. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        PlanRuleLifecycle.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        PlanRuleLifecycle.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 cold_storage_after: Optional[int] = None,
                 delete_after: Optional[int] = None):
        """
        :param int cold_storage_after: Specifies the number of days after creation that a recovery point is moved to cold storage.
        :param int delete_after: Specifies the number of days after creation that a recovery point is deleted. Must be 90 days greater than `cold_storage_after`.
        """
        if cold_storage_after is not None:
            pulumi.set(__self__, "cold_storage_after", cold_storage_after)
        if delete_after is not None:
            pulumi.set(__self__, "delete_after", delete_after)

    @property
    @pulumi.getter(name="coldStorageAfter")
    def cold_storage_after(self) -> Optional[int]:
        """
        Specifies the number of days after creation that a recovery point is moved to cold storage.
        """
        return pulumi.get(self, "cold_storage_after")

    @property
    @pulumi.getter(name="deleteAfter")
    def delete_after(self) -> Optional[int]:
        """
        Specifies the number of days after creation that a recovery point is deleted. Must be 90 days greater than `cold_storage_after`.
        """
        return pulumi.get(self, "delete_after")


@pulumi.output_type
class SelectionCondition(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "stringEquals":
            suggest = "string_equals"
        elif key == "stringLikes":
            suggest = "string_likes"
        elif key == "stringNotEquals":
            suggest = "string_not_equals"
        elif key == "stringNotLikes":
            suggest = "string_not_likes"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in SelectionCondition. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        SelectionCondition.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        SelectionCondition.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 string_equals: Optional[Sequence['outputs.SelectionConditionStringEqual']] = None,
                 string_likes: Optional[Sequence['outputs.SelectionConditionStringLike']] = None,
                 string_not_equals: Optional[Sequence['outputs.SelectionConditionStringNotEqual']] = None,
                 string_not_likes: Optional[Sequence['outputs.SelectionConditionStringNotLike']] = None):
        if string_equals is not None:
            pulumi.set(__self__, "string_equals", string_equals)
        if string_likes is not None:
            pulumi.set(__self__, "string_likes", string_likes)
        if string_not_equals is not None:
            pulumi.set(__self__, "string_not_equals", string_not_equals)
        if string_not_likes is not None:
            pulumi.set(__self__, "string_not_likes", string_not_likes)

    @property
    @pulumi.getter(name="stringEquals")
    def string_equals(self) -> Optional[Sequence['outputs.SelectionConditionStringEqual']]:
        return pulumi.get(self, "string_equals")

    @property
    @pulumi.getter(name="stringLikes")
    def string_likes(self) -> Optional[Sequence['outputs.SelectionConditionStringLike']]:
        return pulumi.get(self, "string_likes")

    @property
    @pulumi.getter(name="stringNotEquals")
    def string_not_equals(self) -> Optional[Sequence['outputs.SelectionConditionStringNotEqual']]:
        return pulumi.get(self, "string_not_equals")

    @property
    @pulumi.getter(name="stringNotLikes")
    def string_not_likes(self) -> Optional[Sequence['outputs.SelectionConditionStringNotLike']]:
        return pulumi.get(self, "string_not_likes")


@pulumi.output_type
class SelectionConditionStringEqual(dict):
    def __init__(__self__, *,
                 key: str,
                 value: str):
        """
        :param str key: The key in a key-value pair.
        :param str value: The value in a key-value pair.
        """
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> str:
        """
        The key in a key-value pair.
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> str:
        """
        The value in a key-value pair.
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class SelectionConditionStringLike(dict):
    def __init__(__self__, *,
                 key: str,
                 value: str):
        """
        :param str key: The key in a key-value pair.
        :param str value: The value in a key-value pair.
        """
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> str:
        """
        The key in a key-value pair.
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> str:
        """
        The value in a key-value pair.
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class SelectionConditionStringNotEqual(dict):
    def __init__(__self__, *,
                 key: str,
                 value: str):
        """
        :param str key: The key in a key-value pair.
        :param str value: The value in a key-value pair.
        """
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> str:
        """
        The key in a key-value pair.
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> str:
        """
        The value in a key-value pair.
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class SelectionConditionStringNotLike(dict):
    def __init__(__self__, *,
                 key: str,
                 value: str):
        """
        :param str key: The key in a key-value pair.
        :param str value: The value in a key-value pair.
        """
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> str:
        """
        The key in a key-value pair.
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> str:
        """
        The value in a key-value pair.
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class SelectionSelectionTag(dict):
    def __init__(__self__, *,
                 key: str,
                 type: str,
                 value: str):
        """
        :param str key: The key in a key-value pair.
        :param str type: An operation, such as `StringEquals`, that is applied to a key-value pair used to filter resources in a selection.
        :param str value: The value in a key-value pair.
        """
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "type", type)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> str:
        """
        The key in a key-value pair.
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def type(self) -> str:
        """
        An operation, such as `StringEquals`, that is applied to a key-value pair used to filter resources in a selection.
        """
        return pulumi.get(self, "type")

    @property
    @pulumi.getter
    def value(self) -> str:
        """
        The value in a key-value pair.
        """
        return pulumi.get(self, "value")





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['ObjectLambdaAccessPointArgs', 'ObjectLambdaAccessPoint']

@pulumi.input_type
class ObjectLambdaAccessPointArgs:
    def __init__(__self__, *,
                 configuration: pulumi.Input['ObjectLambdaAccessPointConfigurationArgs'],
                 account_id: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a ObjectLambdaAccessPoint resource.
        :param pulumi.Input['ObjectLambdaAccessPointConfigurationArgs'] configuration: A configuration block containing details about the Object Lambda Access Point. See Configuration below for more details.
        :param pulumi.Input[str] name: The name for this Object Lambda Access Point.
        """
        pulumi.set(__self__, "configuration", configuration)
        if account_id is not None:
            pulumi.set(__self__, "account_id", account_id)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter
    def configuration(self) -> pulumi.Input['ObjectLambdaAccessPointConfigurationArgs']:
        """
        A configuration block containing details about the Object Lambda Access Point. See Configuration below for more details.
        """
        return pulumi.get(self, "configuration")

    @configuration.setter
    def configuration(self, value: pulumi.Input['ObjectLambdaAccessPointConfigurationArgs']):
        pulumi.set(self, "configuration", value)

    @property
    @pulumi.getter(name="accountId")
    def account_id(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "account_id")

    @account_id.setter
    def account_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "account_id", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name for this Object Lambda Access Point.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class _ObjectLambdaAccessPointState:
    def __init__(__self__, *,
                 account_id: Optional[pulumi.Input[str]] = None,
                 arn: Optional[pulumi.Input[str]] = None,
                 configuration: Optional[pulumi.Input['ObjectLambdaAccessPointConfigurationArgs']] = None,
                 name: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering ObjectLambdaAccessPoint resources.
        :param pulumi.Input[str] arn: Amazon Resource Name (ARN) of the Object Lambda Access Point.
        :param pulumi.Input['ObjectLambdaAccessPointConfigurationArgs'] configuration: A configuration block containing details about the Object Lambda Access Point. See Configuration below for more details.
        :param pulumi.Input[str] name: The name for this Object Lambda Access Point.
        """
        if account_id is not None:
            pulumi.set(__self__, "account_id", account_id)
        if arn is not None:
            pulumi.set(__self__, "arn", arn)
        if configuration is not None:
            pulumi.set(__self__, "configuration", configuration)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter(name="accountId")
    def account_id(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "account_id")

    @account_id.setter
    def account_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "account_id", value)

    @property
    @pulumi.getter
    def arn(self) -> Optional[pulumi.Input[str]]:
        """
        Amazon Resource Name (ARN) of the Object Lambda Access Point.
        """
        return pulumi.get(self, "arn")

    @arn.setter
    def arn(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "arn", value)

    @property
    @pulumi.getter
    def configuration(self) -> Optional[pulumi.Input['ObjectLambdaAccessPointConfigurationArgs']]:
        """
        A configuration block containing details about the Object Lambda Access Point. See Configuration below for more details.
        """
        return pulumi.get(self, "configuration")

    @configuration.setter
    def configuration(self, value: Optional[pulumi.Input['ObjectLambdaAccessPointConfigurationArgs']]):
        pulumi.set(self, "configuration", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name for this Object Lambda Access Point.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)


class ObjectLambdaAccessPoint(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 account_id: Optional[pulumi.Input[str]] = None,
                 configuration: Optional[pulumi.Input[pulumi.InputType['ObjectLambdaAccessPointConfigurationArgs']]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a resource to manage an S3 Object Lambda Access Point.
        An Object Lambda access point is associated with exactly one standard access point and thus one Amazon S3 bucket.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_aws as aws

        example_bucket = aws.s3.Bucket("exampleBucket")
        example_access_point = aws.s3.AccessPoint("exampleAccessPoint", bucket=example_bucket.id)
        example_object_lambda_access_point = aws.s3control.ObjectLambdaAccessPoint("exampleObjectLambdaAccessPoint", configuration=aws.s3control.ObjectLambdaAccessPointConfigurationArgs(
            supporting_access_point=example_access_point.arn,
            transformation_configurations=[aws.s3control.ObjectLambdaAccessPointConfigurationTransformationConfigurationArgs(
                actions=["GetObject"],
                content_transformation=aws.s3control.ObjectLambdaAccessPointConfigurationTransformationConfigurationContentTransformationArgs(
                    aws_lambda=aws.s3control.ObjectLambdaAccessPointConfigurationTransformationConfigurationContentTransformationAwsLambdaArgs(
                        function_arn=aws_lambda_function["example"]["arn"],
                    ),
                ),
            )],
        ))
        ```

        ## Import

        Object Lambda Access Points can be imported using the `account_id` and `name`, separated by a colon (`:`), e.g.

        ```sh
         $ pulumi import aws:s3control/objectLambdaAccessPoint:ObjectLambdaAccessPoint example 123456789012:example
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[pulumi.InputType['ObjectLambdaAccessPointConfigurationArgs']] configuration: A configuration block containing details about the Object Lambda Access Point. See Configuration below for more details.
        :param pulumi.Input[str] name: The name for this Object Lambda Access Point.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ObjectLambdaAccessPointArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a resource to manage an S3 Object Lambda Access Point.
        An Object Lambda access point is associated with exactly one standard access point and thus one Amazon S3 bucket.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_aws as aws

        example_bucket = aws.s3.Bucket("exampleBucket")
        example_access_point = aws.s3.AccessPoint("exampleAccessPoint", bucket=example_bucket.id)
        example_object_lambda_access_point = aws.s3control.ObjectLambdaAccessPoint("exampleObjectLambdaAccessPoint", configuration=aws.s3control.ObjectLambdaAccessPointConfigurationArgs(
            supporting_access_point=example_access_point.arn,
            transformation_configurations=[aws.s3control.ObjectLambdaAccessPointConfigurationTransformationConfigurationArgs(
                actions=["GetObject"],
                content_transformation=aws.s3control.ObjectLambdaAccessPointConfigurationTransformationConfigurationContentTransformationArgs(
                    aws_lambda=aws.s3control.ObjectLambdaAccessPointConfigurationTransformationConfigurationContentTransformationAwsLambdaArgs(
                        function_arn=aws_lambda_function["example"]["arn"],
                    ),
                ),
            )],
        ))
        ```

        ## Import

        Object Lambda Access Points can be imported using the `account_id` and `name`, separated by a colon (`:`), e.g.

        ```sh
         $ pulumi import aws:s3control/objectLambdaAccessPoint:ObjectLambdaAccessPoint example 123456789012:example
        ```

        :param str resource_name: The name of the resource.
        :param ObjectLambdaAccessPointArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ObjectLambdaAccessPointArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 account_id: Optional[pulumi.Input[str]] = None,
                 configuration: Optional[pulumi.Input[pulumi.InputType['ObjectLambdaAccessPointConfigurationArgs']]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = _utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ObjectLambdaAccessPointArgs.__new__(ObjectLambdaAccessPointArgs)

            __props__.__dict__["account_id"] = account_id
            if configuration is None and not opts.urn:
                raise TypeError("Missing required property 'configuration'")
            __props__.__dict__["configuration"] = configuration
            __props__.__dict__["name"] = name
            __props__.__dict__["arn"] = None
        super(ObjectLambdaAccessPoint, __self__).__init__(
            'aws:s3control/objectLambdaAccessPoint:ObjectLambdaAccessPoint',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            account_id: Optional[pulumi.Input[str]] = None,
            arn: Optional[pulumi.Input[str]] = None,
            configuration: Optional[pulumi.Input[pulumi.InputType['ObjectLambdaAccessPointConfigurationArgs']]] = None,
            name: Optional[pulumi.Input[str]] = None) -> 'ObjectLambdaAccessPoint':
        """
        Get an existing ObjectLambdaAccessPoint resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] arn: Amazon Resource Name (ARN) of the Object Lambda Access Point.
        :param pulumi.Input[pulumi.InputType['ObjectLambdaAccessPointConfigurationArgs']] configuration: A configuration block containing details about the Object Lambda Access Point. See Configuration below for more details.
        :param pulumi.Input[str] name: The name for this Object Lambda Access Point.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ObjectLambdaAccessPointState.__new__(_ObjectLambdaAccessPointState)

        __props__.__dict__["account_id"] = account_id
        __props__.__dict__["arn"] = arn
        __props__.__dict__["configuration"] = configuration
        __props__.__dict__["name"] = name
        return ObjectLambdaAccessPoint(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="accountId")
    def account_id(self) -> pulumi.Output[str]:
        return pulumi.get(self, "account_id")

    @property
    @pulumi.getter
    def arn(self) -> pulumi.Output[str]:
        """
        Amazon Resource Name (ARN) of the Object Lambda Access Point.
        """
        return pulumi.get(self, "arn")

    @property
    @pulumi.getter
    def configuration(self) -> pulumi.Output['outputs.ObjectLambdaAccessPointConfiguration']:
        """
        A configuration block containing details about the Object Lambda Access Point. See Configuration below for more details.
        """
        return pulumi.get(self, "configuration")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        The name for this Object Lambda Access Point.
        """
        return pulumi.get(self, "name")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from ._enums import *

__all__ = [
    'AliasRoutingConfigArgs',
    'CodeSigningConfigAllowedPublishersArgs',
    'CodeSigningConfigPoliciesArgs',
    'EventSourceMappingDestinationConfigArgs',
    'EventSourceMappingDestinationConfigOnFailureArgs',
    'EventSourceMappingFilterCriteriaArgs',
    'EventSourceMappingFilterCriteriaFilterArgs',
    'EventSourceMappingSelfManagedEventSourceArgs',
    'EventSourceMappingSourceAccessConfigurationArgs',
    'FunctionDeadLetterConfigArgs',
    'FunctionEnvironmentArgs',
    'FunctionEventInvokeConfigDestinationConfigArgs',
    'FunctionEventInvokeConfigDestinationConfigOnFailureArgs',
    'FunctionEventInvokeConfigDestinationConfigOnSuccessArgs',
    'FunctionFileSystemConfigArgs',
    'FunctionImageConfigArgs',
    'FunctionTracingConfigArgs',
    'FunctionVpcConfigArgs',
]

@pulumi.input_type
class AliasRoutingConfigArgs:
    def __init__(__self__, *,
                 additional_version_weights: Optional[pulumi.Input[Mapping[str, pulumi.Input[float]]]] = None):
        """
        :param pulumi.Input[Mapping[str, pulumi.Input[float]]] additional_version_weights: A map that defines the proportion of events that should be sent to different versions of a lambda function.
        """
        if additional_version_weights is not None:
            pulumi.set(__self__, "additional_version_weights", additional_version_weights)

    @property
    @pulumi.getter(name="additionalVersionWeights")
    def additional_version_weights(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[float]]]]:
        """
        A map that defines the proportion of events that should be sent to different versions of a lambda function.
        """
        return pulumi.get(self, "additional_version_weights")

    @additional_version_weights.setter
    def additional_version_weights(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[float]]]]):
        pulumi.set(self, "additional_version_weights", value)


@pulumi.input_type
class CodeSigningConfigAllowedPublishersArgs:
    def __init__(__self__, *,
                 signing_profile_version_arns: pulumi.Input[Sequence[pulumi.Input[str]]]):
        """
        :param pulumi.Input[Sequence[pulumi.Input[str]]] signing_profile_version_arns: The Amazon Resource Name (ARN) for each of the signing profiles. A signing profile defines a trusted user who can sign a code package.
        """
        pulumi.set(__self__, "signing_profile_version_arns", signing_profile_version_arns)

    @property
    @pulumi.getter(name="signingProfileVersionArns")
    def signing_profile_version_arns(self) -> pulumi.Input[Sequence[pulumi.Input[str]]]:
        """
        The Amazon Resource Name (ARN) for each of the signing profiles. A signing profile defines a trusted user who can sign a code package.
        """
        return pulumi.get(self, "signing_profile_version_arns")

    @signing_profile_version_arns.setter
    def signing_profile_version_arns(self, value: pulumi.Input[Sequence[pulumi.Input[str]]]):
        pulumi.set(self, "signing_profile_version_arns", value)


@pulumi.input_type
class CodeSigningConfigPoliciesArgs:
    def __init__(__self__, *,
                 untrusted_artifact_on_deployment: pulumi.Input[str]):
        """
        :param pulumi.Input[str] untrusted_artifact_on_deployment: Code signing configuration policy for deployment validation failure. If you set the policy to Enforce, Lambda blocks the deployment request if code-signing validation checks fail. If you set the policy to Warn, Lambda allows the deployment and creates a CloudWatch log. Valid values: `Warn`, `Enforce`. Default value: `Warn`.
        """
        pulumi.set(__self__, "untrusted_artifact_on_deployment", untrusted_artifact_on_deployment)

    @property
    @pulumi.getter(name="untrustedArtifactOnDeployment")
    def untrusted_artifact_on_deployment(self) -> pulumi.Input[str]:
        """
        Code signing configuration policy for deployment validation failure. If you set the policy to Enforce, Lambda blocks the deployment request if code-signing validation checks fail. If you set the policy to Warn, Lambda allows the deployment and creates a CloudWatch log. Valid values: `Warn`, `Enforce`. Default value: `Warn`.
        """
        return pulumi.get(self, "untrusted_artifact_on_deployment")

    @untrusted_artifact_on_deployment.setter
    def untrusted_artifact_on_deployment(self, value: pulumi.Input[str]):
        pulumi.set(self, "untrusted_artifact_on_deployment", value)


@pulumi.input_type
class EventSourceMappingDestinationConfigArgs:
    def __init__(__self__, *,
                 on_failure: Optional[pulumi.Input['EventSourceMappingDestinationConfigOnFailureArgs']] = None):
        """
        :param pulumi.Input['EventSourceMappingDestinationConfigOnFailureArgs'] on_failure: The destination configuration for failed invocations. Detailed below.
        """
        if on_failure is not None:
            pulumi.set(__self__, "on_failure", on_failure)

    @property
    @pulumi.getter(name="onFailure")
    def on_failure(self) -> Optional[pulumi.Input['EventSourceMappingDestinationConfigOnFailureArgs']]:
        """
        The destination configuration for failed invocations. Detailed below.
        """
        return pulumi.get(self, "on_failure")

    @on_failure.setter
    def on_failure(self, value: Optional[pulumi.Input['EventSourceMappingDestinationConfigOnFailureArgs']]):
        pulumi.set(self, "on_failure", value)


@pulumi.input_type
class EventSourceMappingDestinationConfigOnFailureArgs:
    def __init__(__self__, *,
                 destination_arn: pulumi.Input[str]):
        """
        :param pulumi.Input[str] destination_arn: The Amazon Resource Name (ARN) of the destination resource.
        """
        pulumi.set(__self__, "destination_arn", destination_arn)

    @property
    @pulumi.getter(name="destinationArn")
    def destination_arn(self) -> pulumi.Input[str]:
        """
        The Amazon Resource Name (ARN) of the destination resource.
        """
        return pulumi.get(self, "destination_arn")

    @destination_arn.setter
    def destination_arn(self, value: pulumi.Input[str]):
        pulumi.set(self, "destination_arn", value)


@pulumi.input_type
class EventSourceMappingFilterCriteriaArgs:
    def __init__(__self__, *,
                 filters: Optional[pulumi.Input[Sequence[pulumi.Input['EventSourceMappingFilterCriteriaFilterArgs']]]] = None):
        """
        :param pulumi.Input[Sequence[pulumi.Input['EventSourceMappingFilterCriteriaFilterArgs']]] filters: A set of up to 5 filter. If an event satisfies at least one, Lambda sends the event to the function or adds it to the next batch. Detailed below.
        """
        if filters is not None:
            pulumi.set(__self__, "filters", filters)

    @property
    @pulumi.getter
    def filters(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['EventSourceMappingFilterCriteriaFilterArgs']]]]:
        """
        A set of up to 5 filter. If an event satisfies at least one, Lambda sends the event to the function or adds it to the next batch. Detailed below.
        """
        return pulumi.get(self, "filters")

    @filters.setter
    def filters(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['EventSourceMappingFilterCriteriaFilterArgs']]]]):
        pulumi.set(self, "filters", value)


@pulumi.input_type
class EventSourceMappingFilterCriteriaFilterArgs:
    def __init__(__self__, *,
                 pattern: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] pattern: A filter pattern up to 4096 characters. See [Filter Rule Syntax](https://docs.aws.amazon.com/lambda/latest/dg/invocation-eventfiltering.html#filtering-syntax).
        """
        if pattern is not None:
            pulumi.set(__self__, "pattern", pattern)

    @property
    @pulumi.getter
    def pattern(self) -> Optional[pulumi.Input[str]]:
        """
        A filter pattern up to 4096 characters. See [Filter Rule Syntax](https://docs.aws.amazon.com/lambda/latest/dg/invocation-eventfiltering.html#filtering-syntax).
        """
        return pulumi.get(self, "pattern")

    @pattern.setter
    def pattern(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "pattern", value)


@pulumi.input_type
class EventSourceMappingSelfManagedEventSourceArgs:
    def __init__(__self__, *,
                 endpoints: pulumi.Input[Mapping[str, pulumi.Input[str]]]):
        """
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] endpoints: A map of endpoints for the self managed source.  For Kafka self-managed sources, the key should be `KAFKA_BOOTSTRAP_SERVERS` and the value should be a string with a comma separated list of broker endpoints.
        """
        pulumi.set(__self__, "endpoints", endpoints)

    @property
    @pulumi.getter
    def endpoints(self) -> pulumi.Input[Mapping[str, pulumi.Input[str]]]:
        """
        A map of endpoints for the self managed source.  For Kafka self-managed sources, the key should be `KAFKA_BOOTSTRAP_SERVERS` and the value should be a string with a comma separated list of broker endpoints.
        """
        return pulumi.get(self, "endpoints")

    @endpoints.setter
    def endpoints(self, value: pulumi.Input[Mapping[str, pulumi.Input[str]]]):
        pulumi.set(self, "endpoints", value)


@pulumi.input_type
class EventSourceMappingSourceAccessConfigurationArgs:
    def __init__(__self__, *,
                 type: pulumi.Input[str],
                 uri: pulumi.Input[str]):
        """
        :param pulumi.Input[str] type: The type of this configuration.  For Self Managed Kafka you will need to supply blocks for type `VPC_SUBNET` and `VPC_SECURITY_GROUP`.
        :param pulumi.Input[str] uri: The URI for this configuration.  For type `VPC_SUBNET` the value should be `subnet:subnet_id` where `subnet_id` is the value you would find in an ec2.Subnet resource's id attribute.  For type `VPC_SECURITY_GROUP` the value should be `security_group:security_group_id` where `security_group_id` is the value you would find in an ec2.SecurityGroup resource's id attribute.
        """
        pulumi.set(__self__, "type", type)
        pulumi.set(__self__, "uri", uri)

    @property
    @pulumi.getter
    def type(self) -> pulumi.Input[str]:
        """
        The type of this configuration.  For Self Managed Kafka you will need to supply blocks for type `VPC_SUBNET` and `VPC_SECURITY_GROUP`.
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: pulumi.Input[str]):
        pulumi.set(self, "type", value)

    @property
    @pulumi.getter
    def uri(self) -> pulumi.Input[str]:
        """
        The URI for this configuration.  For type `VPC_SUBNET` the value should be `subnet:subnet_id` where `subnet_id` is the value you would find in an ec2.Subnet resource's id attribute.  For type `VPC_SECURITY_GROUP` the value should be `security_group:security_group_id` where `security_group_id` is the value you would find in an ec2.SecurityGroup resource's id attribute.
        """
        return pulumi.get(self, "uri")

    @uri.setter
    def uri(self, value: pulumi.Input[str]):
        pulumi.set(self, "uri", value)


@pulumi.input_type
class FunctionDeadLetterConfigArgs:
    def __init__(__self__, *,
                 target_arn: pulumi.Input[str]):
        """
        :param pulumi.Input[str] target_arn: ARN of an SNS topic or SQS queue to notify when an invocation fails. If this option is used, the function's IAM role must be granted suitable access to write to the target object, which means allowing either the `sns:Publish` or `sqs:SendMessage` action on this ARN, depending on which service is targeted.
        """
        pulumi.set(__self__, "target_arn", target_arn)

    @property
    @pulumi.getter(name="targetArn")
    def target_arn(self) -> pulumi.Input[str]:
        """
        ARN of an SNS topic or SQS queue to notify when an invocation fails. If this option is used, the function's IAM role must be granted suitable access to write to the target object, which means allowing either the `sns:Publish` or `sqs:SendMessage` action on this ARN, depending on which service is targeted.
        """
        return pulumi.get(self, "target_arn")

    @target_arn.setter
    def target_arn(self, value: pulumi.Input[str]):
        pulumi.set(self, "target_arn", value)


@pulumi.input_type
class FunctionEnvironmentArgs:
    def __init__(__self__, *,
                 variables: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None):
        """
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] variables: Map of environment variables that are accessible from the function code during execution.
        """
        if variables is not None:
            pulumi.set(__self__, "variables", variables)

    @property
    @pulumi.getter
    def variables(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        Map of environment variables that are accessible from the function code during execution.
        """
        return pulumi.get(self, "variables")

    @variables.setter
    def variables(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "variables", value)


@pulumi.input_type
class FunctionEventInvokeConfigDestinationConfigArgs:
    def __init__(__self__, *,
                 on_failure: Optional[pulumi.Input['FunctionEventInvokeConfigDestinationConfigOnFailureArgs']] = None,
                 on_success: Optional[pulumi.Input['FunctionEventInvokeConfigDestinationConfigOnSuccessArgs']] = None):
        """
        :param pulumi.Input['FunctionEventInvokeConfigDestinationConfigOnFailureArgs'] on_failure: Configuration block with destination configuration for failed asynchronous invocations. See below for details.
        :param pulumi.Input['FunctionEventInvokeConfigDestinationConfigOnSuccessArgs'] on_success: Configuration block with destination configuration for successful asynchronous invocations. See below for details.
        """
        if on_failure is not None:
            pulumi.set(__self__, "on_failure", on_failure)
        if on_success is not None:
            pulumi.set(__self__, "on_success", on_success)

    @property
    @pulumi.getter(name="onFailure")
    def on_failure(self) -> Optional[pulumi.Input['FunctionEventInvokeConfigDestinationConfigOnFailureArgs']]:
        """
        Configuration block with destination configuration for failed asynchronous invocations. See below for details.
        """
        return pulumi.get(self, "on_failure")

    @on_failure.setter
    def on_failure(self, value: Optional[pulumi.Input['FunctionEventInvokeConfigDestinationConfigOnFailureArgs']]):
        pulumi.set(self, "on_failure", value)

    @property
    @pulumi.getter(name="onSuccess")
    def on_success(self) -> Optional[pulumi.Input['FunctionEventInvokeConfigDestinationConfigOnSuccessArgs']]:
        """
        Configuration block with destination configuration for successful asynchronous invocations. See below for details.
        """
        return pulumi.get(self, "on_success")

    @on_success.setter
    def on_success(self, value: Optional[pulumi.Input['FunctionEventInvokeConfigDestinationConfigOnSuccessArgs']]):
        pulumi.set(self, "on_success", value)


@pulumi.input_type
class FunctionEventInvokeConfigDestinationConfigOnFailureArgs:
    def __init__(__self__, *,
                 destination: pulumi.Input[str]):
        """
        :param pulumi.Input[str] destination: Amazon Resource Name (ARN) of the destination resource. See the [Lambda Developer Guide](https://docs.aws.amazon.com/lambda/latest/dg/invocation-async.html#invocation-async-destinations) for acceptable resource types and associated IAM permissions.
        """
        pulumi.set(__self__, "destination", destination)

    @property
    @pulumi.getter
    def destination(self) -> pulumi.Input[str]:
        """
        Amazon Resource Name (ARN) of the destination resource. See the [Lambda Developer Guide](https://docs.aws.amazon.com/lambda/latest/dg/invocation-async.html#invocation-async-destinations) for acceptable resource types and associated IAM permissions.
        """
        return pulumi.get(self, "destination")

    @destination.setter
    def destination(self, value: pulumi.Input[str]):
        pulumi.set(self, "destination", value)


@pulumi.input_type
class FunctionEventInvokeConfigDestinationConfigOnSuccessArgs:
    def __init__(__self__, *,
                 destination: pulumi.Input[str]):
        """
        :param pulumi.Input[str] destination: Amazon Resource Name (ARN) of the destination resource. See the [Lambda Developer Guide](https://docs.aws.amazon.com/lambda/latest/dg/invocation-async.html#invocation-async-destinations) for acceptable resource types and associated IAM permissions.
        """
        pulumi.set(__self__, "destination", destination)

    @property
    @pulumi.getter
    def destination(self) -> pulumi.Input[str]:
        """
        Amazon Resource Name (ARN) of the destination resource. See the [Lambda Developer Guide](https://docs.aws.amazon.com/lambda/latest/dg/invocation-async.html#invocation-async-destinations) for acceptable resource types and associated IAM permissions.
        """
        return pulumi.get(self, "destination")

    @destination.setter
    def destination(self, value: pulumi.Input[str]):
        pulumi.set(self, "destination", value)


@pulumi.input_type
class FunctionFileSystemConfigArgs:
    def __init__(__self__, *,
                 arn: pulumi.Input[str],
                 local_mount_path: pulumi.Input[str]):
        """
        :param pulumi.Input[str] arn: Amazon Resource Name (ARN) of the Amazon EFS Access Point that provides access to the file system.
        :param pulumi.Input[str] local_mount_path: Path where the function can access the file system, starting with /mnt/.
        """
        pulumi.set(__self__, "arn", arn)
        pulumi.set(__self__, "local_mount_path", local_mount_path)

    @property
    @pulumi.getter
    def arn(self) -> pulumi.Input[str]:
        """
        Amazon Resource Name (ARN) of the Amazon EFS Access Point that provides access to the file system.
        """
        return pulumi.get(self, "arn")

    @arn.setter
    def arn(self, value: pulumi.Input[str]):
        pulumi.set(self, "arn", value)

    @property
    @pulumi.getter(name="localMountPath")
    def local_mount_path(self) -> pulumi.Input[str]:
        """
        Path where the function can access the file system, starting with /mnt/.
        """
        return pulumi.get(self, "local_mount_path")

    @local_mount_path.setter
    def local_mount_path(self, value: pulumi.Input[str]):
        pulumi.set(self, "local_mount_path", value)


@pulumi.input_type
class FunctionImageConfigArgs:
    def __init__(__self__, *,
                 commands: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 entry_points: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 working_directory: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[Sequence[pulumi.Input[str]]] commands: Parameters that you want to pass in with `entry_point`.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] entry_points: Entry point to your application, which is typically the location of the runtime executable.
        :param pulumi.Input[str] working_directory: Working directory.
        """
        if commands is not None:
            pulumi.set(__self__, "commands", commands)
        if entry_points is not None:
            pulumi.set(__self__, "entry_points", entry_points)
        if working_directory is not None:
            pulumi.set(__self__, "working_directory", working_directory)

    @property
    @pulumi.getter
    def commands(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        Parameters that you want to pass in with `entry_point`.
        """
        return pulumi.get(self, "commands")

    @commands.setter
    def commands(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "commands", value)

    @property
    @pulumi.getter(name="entryPoints")
    def entry_points(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        Entry point to your application, which is typically the location of the runtime executable.
        """
        return pulumi.get(self, "entry_points")

    @entry_points.setter
    def entry_points(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "entry_points", value)

    @property
    @pulumi.getter(name="workingDirectory")
    def working_directory(self) -> Optional[pulumi.Input[str]]:
        """
        Working directory.
        """
        return pulumi.get(self, "working_directory")

    @working_directory.setter
    def working_directory(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "working_directory", value)


@pulumi.input_type
class FunctionTracingConfigArgs:
    def __init__(__self__, *,
                 mode: pulumi.Input[str]):
        """
        :param pulumi.Input[str] mode: Whether to to sample and trace a subset of incoming requests with AWS X-Ray. Valid values are `PassThrough` and `Active`. If `PassThrough`, Lambda will only trace the request from an upstream service if it contains a tracing header with "sampled=1". If `Active`, Lambda will respect any tracing header it receives from an upstream service. If no tracing header is received, Lambda will call X-Ray for a tracing decision.
        """
        pulumi.set(__self__, "mode", mode)

    @property
    @pulumi.getter
    def mode(self) -> pulumi.Input[str]:
        """
        Whether to to sample and trace a subset of incoming requests with AWS X-Ray. Valid values are `PassThrough` and `Active`. If `PassThrough`, Lambda will only trace the request from an upstream service if it contains a tracing header with "sampled=1". If `Active`, Lambda will respect any tracing header it receives from an upstream service. If no tracing header is received, Lambda will call X-Ray for a tracing decision.
        """
        return pulumi.get(self, "mode")

    @mode.setter
    def mode(self, value: pulumi.Input[str]):
        pulumi.set(self, "mode", value)


@pulumi.input_type
class FunctionVpcConfigArgs:
    def __init__(__self__, *,
                 security_group_ids: pulumi.Input[Sequence[pulumi.Input[str]]],
                 subnet_ids: pulumi.Input[Sequence[pulumi.Input[str]]],
                 vpc_id: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[Sequence[pulumi.Input[str]]] security_group_ids: List of security group IDs associated with the Lambda function.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] subnet_ids: List of subnet IDs associated with the Lambda function.
        """
        pulumi.set(__self__, "security_group_ids", security_group_ids)
        pulumi.set(__self__, "subnet_ids", subnet_ids)
        if vpc_id is not None:
            pulumi.set(__self__, "vpc_id", vpc_id)

    @property
    @pulumi.getter(name="securityGroupIds")
    def security_group_ids(self) -> pulumi.Input[Sequence[pulumi.Input[str]]]:
        """
        List of security group IDs associated with the Lambda function.
        """
        return pulumi.get(self, "security_group_ids")

    @security_group_ids.setter
    def security_group_ids(self, value: pulumi.Input[Sequence[pulumi.Input[str]]]):
        pulumi.set(self, "security_group_ids", value)

    @property
    @pulumi.getter(name="subnetIds")
    def subnet_ids(self) -> pulumi.Input[Sequence[pulumi.Input[str]]]:
        """
        List of subnet IDs associated with the Lambda function.
        """
        return pulumi.get(self, "subnet_ids")

    @subnet_ids.setter
    def subnet_ids(self, value: pulumi.Input[Sequence[pulumi.Input[str]]]):
        pulumi.set(self, "subnet_ids", value)

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "vpc_id")

    @vpc_id.setter
    def vpc_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "vpc_id", value)





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetNetworkInterfaceResult',
    'AwaitableGetNetworkInterfaceResult',
    'get_network_interface',
    'get_network_interface_output',
]

@pulumi.output_type
class GetNetworkInterfaceResult:
    """
    A collection of values returned by getNetworkInterface.
    """
    def __init__(__self__, arn=None, associations=None, attachments=None, availability_zone=None, description=None, filters=None, id=None, interface_type=None, ipv6_addresses=None, mac_address=None, outpost_arn=None, owner_id=None, private_dns_name=None, private_ip=None, private_ips=None, requester_id=None, security_groups=None, subnet_id=None, tags=None, vpc_id=None):
        if arn and not isinstance(arn, str):
            raise TypeError("Expected argument 'arn' to be a str")
        pulumi.set(__self__, "arn", arn)
        if associations and not isinstance(associations, list):
            raise TypeError("Expected argument 'associations' to be a list")
        pulumi.set(__self__, "associations", associations)
        if attachments and not isinstance(attachments, list):
            raise TypeError("Expected argument 'attachments' to be a list")
        pulumi.set(__self__, "attachments", attachments)
        if availability_zone and not isinstance(availability_zone, str):
            raise TypeError("Expected argument 'availability_zone' to be a str")
        pulumi.set(__self__, "availability_zone", availability_zone)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if filters and not isinstance(filters, list):
            raise TypeError("Expected argument 'filters' to be a list")
        pulumi.set(__self__, "filters", filters)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if interface_type and not isinstance(interface_type, str):
            raise TypeError("Expected argument 'interface_type' to be a str")
        pulumi.set(__self__, "interface_type", interface_type)
        if ipv6_addresses and not isinstance(ipv6_addresses, list):
            raise TypeError("Expected argument 'ipv6_addresses' to be a list")
        pulumi.set(__self__, "ipv6_addresses", ipv6_addresses)
        if mac_address and not isinstance(mac_address, str):
            raise TypeError("Expected argument 'mac_address' to be a str")
        pulumi.set(__self__, "mac_address", mac_address)
        if outpost_arn and not isinstance(outpost_arn, str):
            raise TypeError("Expected argument 'outpost_arn' to be a str")
        pulumi.set(__self__, "outpost_arn", outpost_arn)
        if owner_id and not isinstance(owner_id, str):
            raise TypeError("Expected argument 'owner_id' to be a str")
        pulumi.set(__self__, "owner_id", owner_id)
        if private_dns_name and not isinstance(private_dns_name, str):
            raise TypeError("Expected argument 'private_dns_name' to be a str")
        pulumi.set(__self__, "private_dns_name", private_dns_name)
        if private_ip and not isinstance(private_ip, str):
            raise TypeError("Expected argument 'private_ip' to be a str")
        pulumi.set(__self__, "private_ip", private_ip)
        if private_ips and not isinstance(private_ips, list):
            raise TypeError("Expected argument 'private_ips' to be a list")
        pulumi.set(__self__, "private_ips", private_ips)
        if requester_id and not isinstance(requester_id, str):
            raise TypeError("Expected argument 'requester_id' to be a str")
        pulumi.set(__self__, "requester_id", requester_id)
        if security_groups and not isinstance(security_groups, list):
            raise TypeError("Expected argument 'security_groups' to be a list")
        pulumi.set(__self__, "security_groups", security_groups)
        if subnet_id and not isinstance(subnet_id, str):
            raise TypeError("Expected argument 'subnet_id' to be a str")
        pulumi.set(__self__, "subnet_id", subnet_id)
        if tags and not isinstance(tags, dict):
            raise TypeError("Expected argument 'tags' to be a dict")
        pulumi.set(__self__, "tags", tags)
        if vpc_id and not isinstance(vpc_id, str):
            raise TypeError("Expected argument 'vpc_id' to be a str")
        pulumi.set(__self__, "vpc_id", vpc_id)

    @property
    @pulumi.getter
    def arn(self) -> str:
        """
        The ARN of the network interface.
        """
        return pulumi.get(self, "arn")

    @property
    @pulumi.getter
    def associations(self) -> Sequence['outputs.GetNetworkInterfaceAssociationResult']:
        """
        The association information for an Elastic IP address (IPv4) associated with the network interface. See supported fields below.
        """
        return pulumi.get(self, "associations")

    @property
    @pulumi.getter
    def attachments(self) -> Sequence['outputs.GetNetworkInterfaceAttachmentResult']:
        return pulumi.get(self, "attachments")

    @property
    @pulumi.getter(name="availabilityZone")
    def availability_zone(self) -> str:
        """
        The Availability Zone.
        """
        return pulumi.get(self, "availability_zone")

    @property
    @pulumi.getter
    def description(self) -> str:
        """
        Description of the network interface.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def filters(self) -> Optional[Sequence['outputs.GetNetworkInterfaceFilterResult']]:
        return pulumi.get(self, "filters")

    @property
    @pulumi.getter
    def id(self) -> str:
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="interfaceType")
    def interface_type(self) -> str:
        """
        The type of interface.
        """
        return pulumi.get(self, "interface_type")

    @property
    @pulumi.getter(name="ipv6Addresses")
    def ipv6_addresses(self) -> Sequence[str]:
        """
        List of IPv6 addresses to assign to the ENI.
        """
        return pulumi.get(self, "ipv6_addresses")

    @property
    @pulumi.getter(name="macAddress")
    def mac_address(self) -> str:
        """
        The MAC address.
        """
        return pulumi.get(self, "mac_address")

    @property
    @pulumi.getter(name="outpostArn")
    def outpost_arn(self) -> str:
        """
        The Amazon Resource Name (ARN) of the Outpost.
        """
        return pulumi.get(self, "outpost_arn")

    @property
    @pulumi.getter(name="ownerId")
    def owner_id(self) -> str:
        """
        The AWS account ID of the owner of the network interface.
        """
        return pulumi.get(self, "owner_id")

    @property
    @pulumi.getter(name="privateDnsName")
    def private_dns_name(self) -> str:
        """
        The private DNS name.
        """
        return pulumi.get(self, "private_dns_name")

    @property
    @pulumi.getter(name="privateIp")
    def private_ip(self) -> str:
        """
        The private IPv4 address of the network interface within the subnet.
        """
        return pulumi.get(self, "private_ip")

    @property
    @pulumi.getter(name="privateIps")
    def private_ips(self) -> Sequence[str]:
        """
        The private IPv4 addresses associated with the network interface.
        """
        return pulumi.get(self, "private_ips")

    @property
    @pulumi.getter(name="requesterId")
    def requester_id(self) -> str:
        """
        The ID of the entity that launched the instance on your behalf.
        """
        return pulumi.get(self, "requester_id")

    @property
    @pulumi.getter(name="securityGroups")
    def security_groups(self) -> Sequence[str]:
        """
        The list of security groups for the network interface.
        """
        return pulumi.get(self, "security_groups")

    @property
    @pulumi.getter(name="subnetId")
    def subnet_id(self) -> str:
        """
        The ID of the subnet.
        """
        return pulumi.get(self, "subnet_id")

    @property
    @pulumi.getter
    def tags(self) -> Mapping[str, str]:
        """
        Any tags assigned to the network interface.
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> str:
        """
        The ID of the VPC.
        """
        return pulumi.get(self, "vpc_id")


class AwaitableGetNetworkInterfaceResult(GetNetworkInterfaceResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetNetworkInterfaceResult(
            arn=self.arn,
            associations=self.associations,
            attachments=self.attachments,
            availability_zone=self.availability_zone,
            description=self.description,
            filters=self.filters,
            id=self.id,
            interface_type=self.interface_type,
            ipv6_addresses=self.ipv6_addresses,
            mac_address=self.mac_address,
            outpost_arn=self.outpost_arn,
            owner_id=self.owner_id,
            private_dns_name=self.private_dns_name,
            private_ip=self.private_ip,
            private_ips=self.private_ips,
            requester_id=self.requester_id,
            security_groups=self.security_groups,
            subnet_id=self.subnet_id,
            tags=self.tags,
            vpc_id=self.vpc_id)


def get_network_interface(filters: Optional[Sequence[pulumi.InputType['GetNetworkInterfaceFilterArgs']]] = None,
                          id: Optional[str] = None,
                          tags: Optional[Mapping[str, str]] = None,
                          opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetNetworkInterfaceResult:
    """
    Use this data source to get information about a Network Interface.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_aws as aws

    bar = aws.ec2.get_network_interface(id="eni-01234567")
    ```


    :param Sequence[pulumi.InputType['GetNetworkInterfaceFilterArgs']] filters: One or more name/value pairs to filter off of. There are several valid keys, for a full reference, check out [describe-network-interfaces](https://docs.aws.amazon.com/cli/latest/reference/ec2/describe-network-interfaces.html) in the AWS CLI reference.
    :param str id: The identifier for the network interface.
    :param Mapping[str, str] tags: Any tags assigned to the network interface.
    """
    __args__ = dict()
    __args__['filters'] = filters
    __args__['id'] = id
    __args__['tags'] = tags
    if opts is None:
        opts = pulumi.InvokeOptions()
    if opts.version is None:
        opts.version = _utilities.get_version()
    __ret__ = pulumi.runtime.invoke('aws:ec2/getNetworkInterface:getNetworkInterface', __args__, opts=opts, typ=GetNetworkInterfaceResult).value

    return AwaitableGetNetworkInterfaceResult(
        arn=__ret__.arn,
        associations=__ret__.associations,
        attachments=__ret__.attachments,
        availability_zone=__ret__.availability_zone,
        description=__ret__.description,
        filters=__ret__.filters,
        id=__ret__.id,
        interface_type=__ret__.interface_type,
        ipv6_addresses=__ret__.ipv6_addresses,
        mac_address=__ret__.mac_address,
        outpost_arn=__ret__.outpost_arn,
        owner_id=__ret__.owner_id,
        private_dns_name=__ret__.private_dns_name,
        private_ip=__ret__.private_ip,
        private_ips=__ret__.private_ips,
        requester_id=__ret__.requester_id,
        security_groups=__ret__.security_groups,
        subnet_id=__ret__.subnet_id,
        tags=__ret__.tags,
        vpc_id=__ret__.vpc_id)


@_utilities.lift_output_func(get_network_interface)
def get_network_interface_output(filters: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetNetworkInterfaceFilterArgs']]]]] = None,
                                 id: Optional[pulumi.Input[Optional[str]]] = None,
                                 tags: Optional[pulumi.Input[Optional[Mapping[str, str]]]] = None,
                                 opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetNetworkInterfaceResult]:
    """
    Use this data source to get information about a Network Interface.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_aws as aws

    bar = aws.ec2.get_network_interface(id="eni-01234567")
    ```


    :param Sequence[pulumi.InputType['GetNetworkInterfaceFilterArgs']] filters: One or more name/value pairs to filter off of. There are several valid keys, for a full reference, check out [describe-network-interfaces](https://docs.aws.amazon.com/cli/latest/reference/ec2/describe-network-interfaces.html) in the AWS CLI reference.
    :param str id: The identifier for the network interface.
    :param Mapping[str, str] tags: Any tags assigned to the network interface.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from enum import Enum

__all__ = [
    'ManagedPolicy',
]


class ManagedPolicy(str, Enum):
    AWS_ACCOUNT_ACTIVITY_ACCESS = "arn:aws:iam::aws:policy/AWSAccountActivityAccess"
    AWS_ACCOUNT_USAGE_REPORT_ACCESS = "arn:aws:iam::aws:policy/AWSAccountUsageReportAccess"
    AWS_AGENTLESS_DISCOVERY_SERVICE = "arn:aws:iam::aws:policy/AWSAgentlessDiscoveryService"
    AWS_APPLICATION_DISCOVERY_AGENT_ACCESS = "arn:aws:iam::aws:policy/AWSApplicationDiscoveryAgentAccess"
    AWS_APPLICATION_DISCOVERY_SERVICE_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSApplicationDiscoveryServiceFullAccess"
    AWS_BATCH_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSBatchFullAccess"
    AWS_BATCH_SERVICE_ROLE = "arn:aws:iam::aws:policy/service-role/AWSBatchServiceRole"
    AWS_CERTIFICATE_MANAGER_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSCertificateManagerFullAccess"
    AWS_CERTIFICATE_MANAGER_READ_ONLY = "arn:aws:iam::aws:policy/AWSCertificateManagerReadOnly"
    AWS_CLOUD_FORMATION_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AWSCloudFormationReadOnlyAccess"
    AWS_CLOUD_HSM_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSCloudHSMFullAccess"
    AWS_CLOUD_HSM_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AWSCloudHSMReadOnlyAccess"
    AWS_CLOUD_HSM_ROLE = "arn:aws:iam::aws:policy/service-role/AWSCloudHSMRole"
    AWS_CLOUD_TRAIL_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSCloudTrailFullAccess"
    AWS_CLOUD_TRAIL_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AWSCloudTrailReadOnlyAccess"
    AWS_CLOUD_WATCH_LAMBDA_INSIGHTS_EXECUTION_ROLE_POLICY = "arn:aws:iam::aws:policy/AWSCloudWatchLambdaInsightsExecutionRolePolicy"
    AWS_CODE_BUILD_ADMIN_ACCESS = "arn:aws:iam::aws:policy/AWSCodeBuildAdminAccess"
    AWS_CODE_BUILD_DEVELOPER_ACCESS = "arn:aws:iam::aws:policy/AWSCodeBuildDeveloperAccess"
    AWS_CODE_BUILD_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AWSCodeBuildReadOnlyAccess"
    AWS_CODE_COMMIT_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSCodeCommitFullAccess"
    AWS_CODE_COMMIT_POWER_USER = "arn:aws:iam::aws:policy/AWSCodeCommitPowerUser"
    AWS_CODE_COMMIT_READ_ONLY = "arn:aws:iam::aws:policy/AWSCodeCommitReadOnly"
    AWS_CODE_DEPLOY_DEPLOYER_ACCESS = "arn:aws:iam::aws:policy/AWSCodeDeployDeployerAccess"
    AWS_CODE_DEPLOY_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSCodeDeployFullAccess"
    AWS_CODE_DEPLOY_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AWSCodeDeployReadOnlyAccess"
    AWS_CODE_DEPLOY_ROLE = "arn:aws:iam::aws:policy/service-role/AWSCodeDeployRole"
    AWS_CODE_DEPLOY_ROLE_FOR_ECS = "arn:aws:iam::aws:policy/AWSCodeDeployRoleForECS"
    AWS_CODE_PIPELINE_APPROVER_ACCESS = "arn:aws:iam::aws:policy/AWSCodePipelineApproverAccess"
    AWS_CODE_PIPELINE_CUSTOM_ACTION_ACCESS = "arn:aws:iam::aws:policy/AWSCodePipelineCustomActionAccess"
    AWS_CODE_PIPELINE_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSCodePipelineFullAccess"
    AWS_CODE_PIPELINE_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AWSCodePipelineReadOnlyAccess"
    AWS_CODE_STAR_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSCodeStarFullAccess"
    AWS_CODE_STAR_SERVICE_ROLE = "arn:aws:iam::aws:policy/service-role/AWSCodeStarServiceRole"
    AWS_CONFIG_ROLE = "arn:aws:iam::aws:policy/service-role/AWSConfigRole"
    AWS_CONFIG_RULES_EXECUTION_ROLE = "arn:aws:iam::aws:policy/service-role/AWSConfigRulesExecutionRole"
    AWS_CONFIG_USER_ACCESS = "arn:aws:iam::aws:policy/AWSConfigUserAccess"
    AWS_CONNECTOR = "arn:aws:iam::aws:policy/AWSConnector"
    AWS_DATA_PIPELINE_ROLE = "arn:aws:iam::aws:policy/service-role/AWSDataPipelineRole"
    AWS_DATA_PIPELINE_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSDataPipeline_FullAccess"
    AWS_DATA_PIPELINE_POWER_USER = "arn:aws:iam::aws:policy/AWSDataPipeline_PowerUser"
    AWS_DEVICE_FARM_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSDeviceFarmFullAccess"
    AWS_DIRECT_CONNECT_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSDirectConnectFullAccess"
    AWS_DIRECT_CONNECT_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AWSDirectConnectReadOnlyAccess"
    AWS_DIRECTORY_SERVICE_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSDirectoryServiceFullAccess"
    AWS_DIRECTORY_SERVICE_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AWSDirectoryServiceReadOnlyAccess"
    AWS_ELASTIC_BEANSTALK_CUSTOM_PLATFORMFOR_EC2_ROLE = "arn:aws:iam::aws:policy/AWSElasticBeanstalkCustomPlatformforEC2Role"
    AWS_ELASTIC_BEANSTALK_ENHANCED_HEALTH = "arn:aws:iam::aws:policy/service-role/AWSElasticBeanstalkEnhancedHealth"
    AWS_ELASTIC_BEANSTALK_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSElasticBeanstalkFullAccess"
    AWS_ELASTIC_BEANSTALK_MULTICONTAINER_DOCKER = "arn:aws:iam::aws:policy/AWSElasticBeanstalkMulticontainerDocker"
    AWS_ELASTIC_BEANSTALK_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AWSElasticBeanstalkReadOnlyAccess"
    AWS_ELASTIC_BEANSTALK_SERVICE = "arn:aws:iam::aws:policy/service-role/AWSElasticBeanstalkService"
    AWS_ELASTIC_BEANSTALK_WEB_TIER = "arn:aws:iam::aws:policy/AWSElasticBeanstalkWebTier"
    AWS_ELASTIC_BEANSTAK_WORKER_TIER = "arn:aws:iam::aws:policy/AWSElasticBeanstalkWorkerTier"
    AWS_GREENGRASS_FULLCCESS = "arn:aws:iam::aws:policy/AWSGreengrassFullAccess"
    AWS_GREENGRASS_RESOURCE_ACCESS_ROLE_POLICY = "arn:aws:iam::aws:policy/service-role/AWSGreengrassResourceAccessRolePolicy"
    AWS_HEALTH_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSHealthFullAccess"
    AWS_IMPORT_EXPORT_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSImportExportFullAccess"
    AWS_IMPORT_EXPORT_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AWSImportExportReadOnlyAccess"
    AWS_IO_T_CONFIG_ACCESS = "arn:aws:iam::aws:policy/AWSIoTConfigAccess"
    AWS_IO_T_CONFIG_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AWSIoTConfigReadOnlyAccess"
    AWS_IO_T_DATA_ACCESS = "arn:aws:iam::aws:policy/AWSIoTDataAccess"
    AWS_IO_T_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSIoTFullAccess"
    AWS_IO_T_LOGGING = "arn:aws:iam::aws:policy/service-role/AWSIoTLogging"
    AWS_IO_T_RULE_ACTIONS = "arn:aws:iam::aws:policy/service-role/AWSIoTRuleActions"
    AWS_KEY_MANAGEMENT_SERVICE_POWER_USER = "arn:aws:iam::aws:policy/AWSKeyManagementServicePowerUser"
    AWS_LAMBDA_BASIC_EXECUTION_ROLE = "arn:aws:iam::aws:policy/service-role/AWSLambdaBasicExecutionRole"
    AWS_LAMBDA_DYNAMO_DB_EXECUTION_ROLE = "arn:aws:iam::aws:policy/service-role/AWSLambdaDynamoDBExecutionRole"
    AWS_LAMBDA_ENI_MANAGEMENT_ACCESS = "arn:aws:iam::aws:policy/service-role/AWSLambdaENIManagementAccess"
    AWS_LAMBDA_EXECUTE = "arn:aws:iam::aws:policy/AWSLambdaExecute"
    AWS_LAMBDA_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSLambdaFullAccess"
    LAMBDA_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSLambda_FullAccess"
    AWS_LAMBDA_INVOCATION_DYNAMO_DB = "arn:aws:iam::aws:policy/AWSLambdaInvocation-DynamoDB"
    AWS_LAMBDA_KINESIS_EXECUTION_ROLE = "arn:aws:iam::aws:policy/service-role/AWSLambdaKinesisExecutionRole"
    AWS_LAMBDA_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AWSLambdaReadOnlyAccess"
    LAMBDA_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AWSLambda_ReadOnlyAccess"
    AWS_LAMBDA_ROLE = "arn:aws:iam::aws:policy/service-role/AWSLambdaRole"
    AWS_LAMBDA_VPC_ACCESS_EXECUTION_ROLE = "arn:aws:iam::aws:policy/service-role/AWSLambdaVPCAccessExecutionRole"
    AWS_MARKETPLACE_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSMarketplaceFullAccess"
    AWS_MARKETPLACE_GET_ENTITLEMENTS = "arn:aws:iam::aws:policy/AWSMarketplaceGetEntitlements"
    AWS_MARKETPLACE_MANAGE_SUBSCRIPTIONS = "arn:aws:iam::aws:policy/AWSMarketplaceManageSubscriptions"
    AWS_MARKETPLACE_METERING_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSMarketplaceMeteringFullAccess"
    AWS_MARKETPLACE_READONLY = "arn:aws:iam::aws:policy/AWSMarketplaceRead-only"
    AWS_MOBILE_HUB_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSMobileHub_FullAccess"
    AWS_MOBILE_HUB_READ_ONLY = "arn:aws:iam::aws:policy/AWSMobileHub_ReadOnly"
    AWS_MOBILE_HUB_SERVICE_USE_ONLY = "arn:aws:iam::aws:policy/service-role/AWSMobileHub_ServiceUseOnly"
    AWS_OPS_WORKS_CM_INSTANCE_PROFILE_ROLE = "arn:aws:iam::aws:policy/AWSOpsWorksCMInstanceProfileRole"
    AWS_OPS_WORKS_CM_SERVICE_ROLE = "arn:aws:iam::aws:policy/service-role/AWSOpsWorksCMServiceRole"
    AWS_OPS_WORKS_CLOUD_WATCH_LOGS = "arn:aws:iam::aws:policy/AWSOpsWorksCloudWatchLogs"
    AWS_OPS_WORKS_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSOpsWorksFullAccess"
    AWS_OPS_WORKS_INSTANCE_REGISTRATION = "arn:aws:iam::aws:policy/AWSOpsWorksInstanceRegistration"
    AWS_OPS_WORKS_REGISTER_CLI = "arn:aws:iam::aws:policy/AWSOpsWorksRegisterCLI"
    AWS_OPS_WORKS_ROLE = "arn:aws:iam::aws:policy/service-role/AWSOpsWorksRole"
    AWS_QUICK_SIGHT_DESCRIBE_RD = "arn:aws:iam::aws:policy/service-role/AWSQuickSightDescribeRDS"
    AWS_QUICK_SIGHT_DESCRIBE_REDSHIFT = "arn:aws:iam::aws:policy/service-role/AWSQuickSightDescribeRedshift"
    AWS_QUICK_SIGHT_LIST_IAM = "arn:aws:iam::aws:policy/service-role/AWSQuickSightListIAM"
    AWS_QUICKSIGHT_ATHENA_ACCESS = "arn:aws:iam::aws:policy/service-role/AWSQuicksightAthenaAccess"
    AWS_STEP_FUNCTIONS_CONSOLE_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSStepFunctionsConsoleFullAccess"
    AWS_STEP_FUNCTIONS_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSStepFunctionsFullAccess"
    AWS_STEP_FUNCTIONS_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AWSStepFunctionsReadOnlyAccess"
    AWS_STORAGE_GATEWAY_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSStorageGatewayFullAccess"
    AWS_STORAGE_GATEWAY_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AWSStorageGatewayReadOnlyAccess"
    AWS_SUPPORT_ACCESS = "arn:aws:iam::aws:policy/AWSSupportAccess"
    AWSWAF_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSWAFFullAccess"
    AWSWAF_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AWSWAFReadOnlyAccess"
    AWS_XRAY_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSXrayFullAccess"
    AWS_XRAY_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AWSXrayReadOnlyAccess"
    AWS_XRAY_WRITE_ONLY_ACCESS = "arn:aws:iam::aws:policy/AWSXrayWriteOnlyAccess"
    AWSX_RAY_DAEMON_WRITE_ACCESS = "arn:aws:iam::aws:policy/AWSXRayDaemonWriteAccess"
    ADMINISTRATOR_ACCESS = "arn:aws:iam::aws:policy/AdministratorAccess"
    AMAZON_API_GATEWAY_ADMINISTRATOR = "arn:aws:iam::aws:policy/AmazonAPIGatewayAdministrator"
    AMAZON_API_GATEWAY_INVOKE_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonAPIGatewayInvokeFullAccess"
    AMAZON_API_GATEWAY_PUSH_TO_CLOUD_WATCH_LOGS = "arn:aws:iam::aws:policy/service-role/AmazonAPIGatewayPushToCloudWatchLogs"
    AMAZON_APP_STREAM_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonAppStreamFullAccess"
    AMAZON_APP_STREAM_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonAppStreamReadOnlyAccess"
    AMAZON_APP_STREAM_SERVICE_ACCESS = "arn:aws:iam::aws:policy/service-role/AmazonAppStreamServiceAccess"
    AMAZON_ATHENA_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonAthenaFullAccess"
    AMAZON_CLOUD_DIRECTORY_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonCloudDirectoryFullAccess"
    AMAZON_CLOUD_DIRECTORY_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonCloudDirectoryReadOnlyAccess"
    AMAZON_COGNITO_DEVELOPER_AUTHENTICATED_IDENTITIES = "arn:aws:iam::aws:policy/AmazonCognitoDeveloperAuthenticatedIdentities"
    AMAZON_COGNITO_POWER_USER = "arn:aws:iam::aws:policy/AmazonCognitoPowerUser"
    AMAZON_COGNITO_READ_ONLY = "arn:aws:iam::aws:policy/AmazonCognitoReadOnly"
    AMAZON_DMS_CLOUD_WATCH_LOGS_ROLE = "arn:aws:iam::aws:policy/service-role/AmazonDMSCloudWatchLogsRole"
    AMAZON_DMS_REDSHIFT_S3_ROLE = "arn:aws:iam::aws:policy/service-role/AmazonDMSRedshiftS3Role"
    AMAZON_DMSVPC_MANAGEMENT_ROLE = "arn:aws:iam::aws:policy/service-role/AmazonDMSVPCManagementRole"
    AMAZON_DRSVPC_MANAGEMENT = "arn:aws:iam::aws:policy/AmazonDRSVPCManagement"
    AMAZON_DYNAMO_DB_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonDynamoDBFullAccess"
    AMAZON_DYNAMO_DB_FULL_ACCESSWITH_DATA_PIPELINE = "arn:aws:iam::aws:policy/AmazonDynamoDBFullAccesswithDataPipeline"
    AMAZON_DYNAMO_DB_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonDynamoDBReadOnlyAccess"
    AMAZON_EC2_CONTAINER_REGISTRY_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonEC2ContainerRegistryFullAccess"
    AMAZON_EC2_CONTAINER_REGISTRY_POWER_USER = "arn:aws:iam::aws:policy/AmazonEC2ContainerRegistryPowerUser"
    AMAZON_EC2_CONTAINER_REGISTRY_READ_ONLY = "arn:aws:iam::aws:policy/AmazonEC2ContainerRegistryReadOnly"
    AMAZON_EC2_CONTAINER_SERVICE_AUTOSCALE_ROLE = "arn:aws:iam::aws:policy/service-role/AmazonEC2ContainerServiceAutoscaleRole"
    AMAZON_EC2_CONTAINER_SERVICE_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonEC2ContainerServiceFullAccess"
    AMAZON_EC2_CONTAINER_SERVICE_ROLE = "arn:aws:iam::aws:policy/service-role/AmazonEC2ContainerServiceRole"
    AMAZON_EC2_CONTAINER_SERVICEFOR_EC2_ROLE = "arn:aws:iam::aws:policy/service-role/AmazonEC2ContainerServiceforEC2Role"
    EC2_INSTANCE_PROFILE_FOR_IMAGE_BUILDER = "arn:aws:iam::aws:policy/EC2InstanceProfileForImageBuilder"
    AMAZON_EC2_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonEC2FullAccess"
    AMAZON_EC2_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonEC2ReadOnlyAccess"
    AMAZON_EC2_REPORTS_ACCESS = "arn:aws:iam::aws:policy/AmazonEC2ReportsAccess"
    AMAZON_EC2_ROLEFOR_AWS_CODE_DEPLOY = "arn:aws:iam::aws:policy/service-role/AmazonEC2RoleforAWSCodeDeploy"
    AMAZON_EC2_ROLEFOR_DATA_PIPELINE_ROLE = "arn:aws:iam::aws:policy/service-role/AmazonEC2RoleforDataPipelineRole"
    AMAZON_EC2_ROLEFOR_SSM = "arn:aws:iam::aws:policy/service-role/AmazonEC2RoleforSSM"
    AMAZON_EC2_SPOT_FLEET_AUTOSCALE_ROLE = "arn:aws:iam::aws:policy/service-role/AmazonEC2SpotFleetAutoscaleRole"
    AMAZON_EC2_SPOT_FLEET_ROLE = "arn:aws:iam::aws:policy/service-role/AmazonEC2SpotFleetRole"
    AMAZON_EC2_SPOT_FLEET_TAGGING_ROLE = "arn:aws:iam::aws:policy/service-role/AmazonEC2SpotFleetTaggingRole"
    AMAZON_ECS_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonECS_FullAccess"
    AMAZON_ECS_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AmazonECSServiceRolePolicy"
    AMAZON_ECS_TASK_EXECUTION_ROLE_POLICY = "arn:aws:iam::aws:policy/service-role/AmazonECSTaskExecutionRolePolicy"
    AMAZON_ES_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonESFullAccess"
    AMAZON_ES_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonESReadOnlyAccess"
    AMAZON_ELASTI_CACHE_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonElastiCacheFullAccess"
    AMAZON_ELASTI_CACHE_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonElastiCacheReadOnlyAccess"
    AMAZON_ELASTIC_FILE_SYSTEM_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonElasticFileSystemFullAccess"
    AMAZON_ELASTIC_FILE_SYSTEM_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonElasticFileSystemReadOnlyAccess"
    AMAZON_ELASTIC_MAP_REDUCE_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonElasticMapReduceFullAccess"
    AMAZON_ELASTIC_MAP_REDUCE_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonElasticMapReduceReadOnlyAccess"
    AMAZON_ELASTIC_MAP_REDUCE_ROLE = "arn:aws:iam::aws:policy/service-role/AmazonElasticMapReduceRole"
    AMAZON_ELASTIC_MAP_REDUCEFOR_AUTO_SCALING_ROLE = "arn:aws:iam::aws:policy/service-role/AmazonElasticMapReduceforAutoScalingRole"
    AMAZON_ELASTIC_MAP_REDUCEFOR_EC2_ROLE = "arn:aws:iam::aws:policy/service-role/AmazonElasticMapReduceforEC2Role"
    AMAZON_ELASTIC_TRANSCODER_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonElasticTranscoderFullAccess"
    AMAZON_ELASTIC_TRANSCODER_JOBS_SUBMITTER = "arn:aws:iam::aws:policy/AmazonElasticTranscoderJobsSubmitter"
    AMAZON_ELASTIC_TRANSCODER_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonElasticTranscoderReadOnlyAccess"
    AMAZON_ELASTIC_TRANSCODER_ROLE = "arn:aws:iam::aws:policy/service-role/AmazonElasticTranscoderRole"
    AMAZON_GLACIER_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonGlacierFullAccess"
    AMAZON_GLACIER_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonGlacierReadOnlyAccess"
    AMAZON_INSPECTOR_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonInspectorFullAccess"
    AMAZON_INSPECTOR_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonInspectorReadOnlyAccess"
    AMAZON_KINESIS_ANALYTICS_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonKinesisAnalyticsFullAccess"
    AMAZON_KINESIS_ANALYTICS_READ_ONLY = "arn:aws:iam::aws:policy/AmazonKinesisAnalyticsReadOnly"
    AMAZON_KINESIS_FIREHOSE_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonKinesisFirehoseFullAccess"
    AMAZON_KINESIS_FIREHOSE_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonKinesisFirehoseReadOnlyAccess"
    AMAZON_KINESIS_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonKinesisFullAccess"
    AMAZON_KINESIS_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonKinesisReadOnlyAccess"
    AMAZON_LEX_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonLexFullAccess"
    AMAZON_LEX_READ_ONLY = "arn:aws:iam::aws:policy/AmazonLexReadOnly"
    AMAZON_LEX_RUN_BOTS_ONLY = "arn:aws:iam::aws:policy/AmazonLexRunBotsOnly"
    AMAZON_MACHINE_LEARNING_BATCH_PREDICTIONS_ACCESS = "arn:aws:iam::aws:policy/AmazonMachineLearningBatchPredictionsAccess"
    AMAZON_MACHINE_LEARNING_CREATE_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonMachineLearningCreateOnlyAccess"
    AMAZON_MACHINE_LEARNING_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonMachineLearningFullAccess"
    AMAZON_MACHINE_LEARNING_MANAGE_REAL_TIME_ENDPOINT_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonMachineLearningManageRealTimeEndpointOnlyAccess"
    AMAZON_MACHINE_LEARNING_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonMachineLearningReadOnlyAccess"
    AMAZON_MACHINE_LEARNING_REAL_TIME_PREDICTION_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonMachineLearningRealTimePredictionOnlyAccess"
    AMAZON_MACHINE_LEARNING_ROLEFOR_REDSHIFT_DATA_SOURCE = "arn:aws:iam::aws:policy/service-role/AmazonMachineLearningRoleforRedshiftDataSource"
    AMAZON_MECHANICAL_TURK_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonMechanicalTurkFullAccess"
    AMAZON_MECHANICAL_TURK_READ_ONLY = "arn:aws:iam::aws:policy/AmazonMechanicalTurkReadOnly"
    AMAZON_MOBILE_ANALYTICS_FINANCIAL_REPORT_ACCESS = "arn:aws:iam::aws:policy/AmazonMobileAnalyticsFinancialReportAccess"
    AMAZON_MOBILE_ANALYTICS_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonMobileAnalyticsFullAccess"
    AMAZON_MOBILE_ANALYTICS_NONFINANCIAL_REPORT_ACCESS = "arn:aws:iam::aws:policy/AmazonMobileAnalyticsNon-financialReportAccess"
    AMAZON_MOBILE_ANALYTICS_WRITE_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonMobileAnalyticsWriteOnlyAccess"
    AMAZON_POLLY_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonPollyFullAccess"
    AMAZON_POLLY_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonPollyReadOnlyAccess"
    AMAZON_RDS_DIRECTORY_SERVICE_ACCESS = "arn:aws:iam::aws:policy/service-role/AmazonRDSDirectoryServiceAccess"
    AMAZON_RDS_ENHANCED_MONITORING_ROLE = "arn:aws:iam::aws:policy/service-role/AmazonRDSEnhancedMonitoringRole"
    AMAZON_RDS_DATA_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonRDSDataFullAccess"
    AMAZON_RDS_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonRDSFullAccess"
    AMAZON_RDS_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonRDSReadOnlyAccess"
    AMAZON_REDSHIFT_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonRedshiftFullAccess"
    AMAZON_REDSHIFT_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonRedshiftReadOnlyAccess"
    AMAZON_REKOGNITION_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonRekognitionFullAccess"
    AMAZON_REKOGNITION_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonRekognitionReadOnlyAccess"
    AMAZON_ROUTE53_DOMAINS_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonRoute53DomainsFullAccess"
    AMAZON_ROUTE53_DOMAINS_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonRoute53DomainsReadOnlyAccess"
    AMAZON_ROUTE53_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonRoute53FullAccess"
    AMAZON_ROUTE53_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonRoute53ReadOnlyAccess"
    AMAZON_S3_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonS3FullAccess"
    AMAZON_S3_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonS3ReadOnlyAccess"
    AMAZON_SES_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonSESFullAccess"
    AMAZON_SES_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonSESReadOnlyAccess"
    AMAZON_SNS_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonSNSFullAccess"
    AMAZON_SNS_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonSNSReadOnlyAccess"
    AMAZON_SNS_ROLE = "arn:aws:iam::aws:policy/service-role/AmazonSNSRole"
    AMAZON_SQS_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonSQSFullAccess"
    AMAZON_SQS_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonSQSReadOnlyAccess"
    AWS_LAMBDA_SQS_QUEUE_EXECUTION_ROLE = "arn:aws:iam::aws:policy/service-role/AWSLambdaSQSQueueExecutionRole"
    AMAZON_SSM_AUTOMATION_APPROVER_ACCESS = "arn:aws:iam::aws:policy/AmazonSSMAutomationApproverAccess"
    AMAZON_SSM_AUTOMATION_ROLE = "arn:aws:iam::aws:policy/service-role/AmazonSSMAutomationRole"
    AMAZON_SSM_DIRECTORY_SERVICE_ACCESS = "arn:aws:iam::aws:policy/AmazonSSMDirectoryServiceAccess"
    AMAZON_SSM_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonSSMFullAccess"
    AMAZON_SSM_MAINTENANCE_WINDOW_ROLE = "arn:aws:iam::aws:policy/service-role/AmazonSSMMaintenanceWindowRole"
    AMAZON_SSM_PATCH_ASSOCIATION = "arn:aws:iam::aws:policy/AmazonSSMPatchAssociation"
    AMAZON_SSM_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonSSMReadOnlyAccess"
    AMAZON_SSM_MANAGED_INSTANCE_CORE = "arn:aws:iam::aws:policy/AmazonSSMManagedInstanceCore"
    AMAZON_VPC_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonVPCFullAccess"
    AMAZON_VPC_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonVPCReadOnlyAccess"
    AMAZON_WORK_MAIL_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonWorkMailFullAccess"
    AMAZON_WORK_MAIL_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonWorkMailReadOnlyAccess"
    AMAZON_WORK_SPACES_ADMIN = "arn:aws:iam::aws:policy/AmazonWorkSpacesAdmin"
    AMAZON_WORK_SPACES_APPLICATION_MANAGER_ADMIN_ACCESS = "arn:aws:iam::aws:policy/AmazonWorkSpacesApplicationManagerAdminAccess"
    AMAZON_ZOCALO_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonZocaloFullAccess"
    AMAZON_ZOCALO_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonZocaloReadOnlyAccess"
    APPLICATION_AUTO_SCALING_FOR_AMAZON_APP_STREAM_ACCESS = "arn:aws:iam::aws:policy/service-role/ApplicationAutoScalingForAmazonAppStreamAccess"
    AUTO_SCALING_CONSOLE_FULL_ACCESS = "arn:aws:iam::aws:policy/AutoScalingConsoleFullAccess"
    AUTO_SCALING_CONSOLE_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AutoScalingConsoleReadOnlyAccess"
    AUTO_SCALING_FULL_ACCESS = "arn:aws:iam::aws:policy/AutoScalingFullAccess"
    AUTO_SCALING_NOTIFICATION_ACCESS_ROLE = "arn:aws:iam::aws:policy/service-role/AutoScalingNotificationAccessRole"
    AUTO_SCALING_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AutoScalingReadOnlyAccess"
    BILLING = "arn:aws:iam::aws:policy/job-function/Billing"
    CLOUD_FRONT_FULL_ACCESS = "arn:aws:iam::aws:policy/CloudFrontFullAccess"
    CLOUD_FRONT_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/CloudFrontReadOnlyAccess"
    CLOUD_SEARCH_FULL_ACCESS = "arn:aws:iam::aws:policy/CloudSearchFullAccess"
    CLOUD_SEARCH_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/CloudSearchReadOnlyAccess"
    CLOUD_WATCH_ACTIONS_EC2_ACCESS = "arn:aws:iam::aws:policy/CloudWatchActionsEC2Access"
    CLOUD_WATCH_EVENTS_BUILT_IN_TARGET_EXECUTION_ACCESS = "arn:aws:iam::aws:policy/service-role/CloudWatchEventsBuiltInTargetExecutionAccess"
    CLOUD_WATCH_EVENTS_FULL_ACCESS = "arn:aws:iam::aws:policy/CloudWatchEventsFullAccess"
    CLOUD_WATCH_EVENTS_INVOCATION_ACCESS = "arn:aws:iam::aws:policy/service-role/CloudWatchEventsInvocationAccess"
    CLOUD_WATCH_EVENTS_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/CloudWatchEventsReadOnlyAccess"
    CLOUD_WATCH_FULL_ACCESS = "arn:aws:iam::aws:policy/CloudWatchFullAccess"
    CLOUD_WATCH_LOGS_FULL_ACCESS = "arn:aws:iam::aws:policy/CloudWatchLogsFullAccess"
    CLOUD_WATCH_LOGS_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/CloudWatchLogsReadOnlyAccess"
    CLOUD_WATCH_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/CloudWatchReadOnlyAccess"
    DATA_SCIENTIST = "arn:aws:iam::aws:policy/job-function/DataScientist"
    DATABASE_ADMINISTRATOR = "arn:aws:iam::aws:policy/job-function/DatabaseAdministrator"
    IAM_FULL_ACCESS = "arn:aws:iam::aws:policy/IAMFullAccess"
    IAM_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/IAMReadOnlyAccess"
    IAM_SELF_MANAGE_SERVICE_SPECIFIC_CREDENTIALS = "arn:aws:iam::aws:policy/IAMSelfManageServiceSpecificCredentials"
    IAMUSER_CHANGE_PASSWORD = "arn:aws:iam::aws:policy/IAMUserChangePassword"
    IAMUSER_SSH_KEYS = "arn:aws:iam::aws:policy/IAMUserSSHKeys"
    NETWORK_ADMINISTRATOR = "arn:aws:iam::aws:policy/job-function/NetworkAdministrator"
    POWER_USER_ACCESS = "arn:aws:iam::aws:policy/PowerUserAccess"
    RDS_CLOUD_HSM_AUTHORIZATION_ROLE = "arn:aws:iam::aws:policy/service-role/RDSCloudHsmAuthorizationRole"
    READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/ReadOnlyAccess"
    RESOURCE_GROUPSAND_TAG_EDITOR_FULL_ACCESS = "arn:aws:iam::aws:policy/ResourceGroupsandTagEditorFullAccess"
    RESOURCE_GROUPSAND_TAG_EDITOR_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/ResourceGroupsandTagEditorReadOnlyAccess"
    SECURITY_AUDIT = "arn:aws:iam::aws:policy/SecurityAudit"
    SERVER_MIGRATION_CONNECTOR = "arn:aws:iam::aws:policy/ServerMigrationConnector"
    SERVER_MIGRATION_SERVICE_ROLE = "arn:aws:iam::aws:policy/service-role/ServerMigrationServiceRole"
    SERVICE_CATALOG_ADMIN_FULL_ACCESS = "arn:aws:iam::aws:policy/ServiceCatalogAdminFullAccess"
    SERVICE_CATALOG_ADMIN_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/ServiceCatalogAdminReadOnlyAccess"
    SERVICE_CATALOG_END_USER_ACCESS = "arn:aws:iam::aws:policy/ServiceCatalogEndUserAccess"
    SERVICE_CATALOG_END_USER_FULL_ACCESS = "arn:aws:iam::aws:policy/ServiceCatalogEndUserFullAccess"
    SIMPLE_WORKFLOW_FULL_ACCESS = "arn:aws:iam::aws:policy/SimpleWorkflowFullAccess"
    SUPPORT_USER = "arn:aws:iam::aws:policy/job-function/SupportUser"
    SYSTEM_ADMINISTRATOR = "arn:aws:iam::aws:policy/job-function/SystemAdministrator"
    VM_IMPORT_EXPORT_ROLE_FOR_AWS_CONNECTOR = "arn:aws:iam::aws:policy/service-role/VMImportExportRoleForAWSConnector"
    VIEW_ONLY_ACCESS = "arn:aws:iam::aws:policy/job-function/ViewOnlyAccess"
